Error 403 (Forbidden)!!1

**403.** That’s an error.

We're sorry, but you do not have access to this page. That’s all we know.

Back


[![Meet the watercolor painting community](https://www.gstatic.com/youtube/img/promos/6ffb2eb0c0fcc1b729e6563a0e70653395e8f71bc721b4655855e5925e0847d5_122x56.webp)](https://www.youtube.com/ "Meet the watercolor painting community")

Skip navigation

Search


Search with your voice

[Sign in](https://accounts.google.com/ServiceLogin?service=youtube&uilel=3&passive=true&continue=https%3A%2F%2Fwww.youtube.com%2Fsignin%3Faction_handle_signin%3Dtrue%26app%3Ddesktop%26hl%3Den%26next%3Dhttps%253A%252F%252Fwww.youtube.com%252Fwatch%253Fv%253Di9YpWp0hXgg&hl=en&ec=65620)

[![Meet the watercolor painting community](https://www.gstatic.com/youtube/img/promos/6ffb2eb0c0fcc1b729e6563a0e70653395e8f71bc721b4655855e5925e0847d5_122x56.webp)](https://www.youtube.com/ "Meet the watercolor painting community")

Hacker News Show #1: termcraft, Switchboard, Fortransky, Entroly, rsloop, GoldenMatch, Banish, capit

Tap to unmute

2x

## Hacker News Show \#1: termcraft, Switchboard, Fortransky, Entroly, rsloop, GoldenMatch, Banish, capit

Github Awesome 3,630 views 1 day ago

Search

Copy link

Info

Shopping

If playback doesn't begin shortly, try restarting your device.

•

You're signed out

Videos you watch may be added to the TV's watch history and influence TV recommendations. To avoid this, cancel and sign in to YouTube on your computer.

CancelConfirm

Up next

Live

Upcoming

CancelPlay Now

[GitHub Trending Today #27: Ichinichi, Recordly, Notchi, gabagool, Antfly, Horizo​​n, Slug, Slim, Lux\\
\\
15:37](https://www.youtube.com/watch?v=19AUlTi-Ki8)

[Trending AI Projects #3: NVIDIA NemoClaw, nightingale, OpenViktor, AutoResearchClaw, OpenHanako\\
\\
15:10](https://www.youtube.com/watch?v=v-6nm3gnh6g)

Hide

Share

Include playlist

An error occurred while retrieving sharing information. Please try again later.

0:00

[Next (SHIFT+n)](https://www.youtube.com/watch?v=v-6nm3gnh6g "Next (SHIFT+n)")

0:03 / 12:51

Live

•Watch full video

•
Introduction

•

[22:48\\
Cursor's new model is NOT what it seems...Wes Roth15K views • 8 hours agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=dtcgzGAeUZA) [1:06:32\\
The End of Coding: Andrej Karpathy on Agents, AutoResearch, and the Loopy Era of AINo Priors: AI, Machine Learning, Tech, & Startups348K views • 2 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=kwSVtQ7dziU) [6:14\\
SNL Hosts Making the Cast BREAK for 6 Minutes StraightPopMojo6.5M views • 11 months agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=tEMvyiHwBFY) [16:10\\
You Need to Stop Using Claude Like a Chatbot. Here’s Why.Dylan Davis25K views • 1 day agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=XKsn3i9yYjU) [11:15\\
AIR CANADA CRJ-900 Collision in NYC La Guardia AirportPilot Blog118K views • 6 hours agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=8vokLcNNGCM) [26:51\\
How Bad is Private Credit?Patrick Boyle513K views • 2 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=8Qc5U00IiAk) [1:01:14\\
Benedict Evans: OpenAI’s Moat Problem & the Future of SoftwareThe MAD Podcast with Matt Turck9.3K views • 4 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=jH2ZIUKvazU) [15:37\\
GitHub Trending Today #27: Ichinichi, Recordly, Notchi, gabagool, Antfly, Horizo​​n, Slug, Slim, LuxGithub Awesome6K views • 2 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=19AUlTi-Ki8) [3:39\\
MAHAspital - SNLSaturday Night Live3.2M views • 8 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=FUBVuvstPCs) [27:48\\
Did Cursor really just rebrand Kimi???Theo - t3․gg47K views • 19 hours agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=QGnKTRtEH50) [15:03\\
Microsoft Just Proved AI Doesn’t Need GPUsDr. Know-it-all Knows it all48K views • 9 days agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=6PJd08t_n0U) [10:29\\
LaGuardia Airport closed after plane collision kills 2CNN129K views • 2 hours agoLivePlaylist ()Mix (50+)](https://www.youtube.com/watch?v=zCLOAKSpq3U)

# Hacker News Show \#1: termcraft, Switchboard, Fortransky, Entroly, rsloop, GoldenMatch, Banish, capit

[![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)](https://www.youtube.com/@GithubAwesome)

[Github Awesome](https://www.youtube.com/@GithubAwesome)


Github Awesome


52.8K subscribers

Join

Subscribe

Subscribed

109

Share

Save

Download

Download

3.6K views1 day ago [#ai](https://www.youtube.com/hashtag/ai) [#github](https://www.youtube.com/hashtag/github) [#opensource](https://www.youtube.com/hashtag/opensource)

3,630 views • Mar 22, 2026 • #ai #github #opensource

Today we're launching something new: the Hacker News Show. Instead of our usual GitHub trending list, we're going straight to the Show HN section, where solo developers post the things they've been building. Thirty projects, hand-picked from the archives.…...more

...more

How this was made

Auto-dubbed

Audio tracks for some languages were automatically generated. [Learn more](https://support.google.com/youtube/answer/15569972?hl=en)

## Chapters         View all

[**Introduction**  **Introduction** \\
\\
0:00](https://www.youtube.com/watch?v=i9YpWp0hXgg)

[**Introduction**](https://www.youtube.com/watch?v=i9YpWp0hXgg)

0:00

[**termcraft**  **termcraft** \\
\\
0:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

[**termcraft**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

0:16

[**Switchboard**  **Switchboard** \\
\\
0:41](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

[**Switchboard**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

0:41

[**Fortransky**  **Fortransky** \\
\\
1:06](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

[**Fortransky**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

1:06

[**pi-worker-agents**  **pi-worker-agents** \\
\\
1:30](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=90s)

[**pi-worker-agents**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=90s)

1:30

[**Entroly**  **Entroly** \\
\\
1:51](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=111s)

[**Entroly**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=111s)

1:51

[**rsloop**  **rsloop** \\
\\
2:18](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=138s)

[**rsloop**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=138s)

2:18

[**GoldenMatch**  **GoldenMatch** \\
\\
2:44](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=164s)

[**GoldenMatch**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=164s)

2:44

Transcript

Follow along using the transcript.

Show transcript

[**Github Awesome**\\
\\
52.8K subscribers](https://www.youtube.com/@GithubAwesome)

[Videos](https://www.youtube.com/channel/UC9Rrud-8CaHokDtK9FszvRg/videos)[About](https://www.youtube.com/channel/UC9Rrud-8CaHokDtK9FszvRg/about)[Tiktok](https://www.youtube.com/redirect?event=Watch_SD_EP&redir_token=QUFFLUhqbk5ROHN6TGQ1Y2xiUzl6dXE2Ym11UzV2X3VXZ3xBQ3Jtc0ttWEdsS2RLVkFMQnRsdHdHcmEtMTlNZDRTakNsUWF4OVYwSjFKWnhmSzk3Ylh1RFJqS1JGNi1oZkVuS2F1SXlPSnVnemNOX1ZtVGhMMlc5YmlOSmNET2VQWm1pcGg0U1c2a1dwN0N1ZUFNaEVMRkc3cw&q=https%3A%2F%2Fwww.tiktok.com%2F%40github.awesome)[Instagram](https://www.youtube.com/redirect?event=Watch_SD_EP&redir_token=QUFFLUhqbWZ6R1YwNHBYUGhQRmZQSmk1VzYzMHVUTTdMQXxBQ3Jtc0tubDJ6NGNsRmdQV2RabzdHZ1BBd2dDdm9sQXJ5Tl84cTFJOWpHQ3Z3dGxMRTNfRG9KYmxPUzQ0eFpOM3hkSU5PWmRQVkZBbEJJSEQ0dXRTb3B1dnZLTUJ2bnMyWmRYb3ctV3FZczYtZG94dkZJUW13dw&q=https%3A%2F%2Fwww.instagram.com%2Fgithub.awesome%2F)

Show less

[#ai](https://www.youtube.com/hashtag/ai) [#github](https://www.youtube.com/hashtag/github) [#opensource](https://www.youtube.com/hashtag/opensource)

# Hacker News Show \#1: termcraft, Switchboard, Fortransky, Entroly, rsloop, GoldenMatch, Banish, capit

3,630 views3.6K views

Mar 22, 2026

109

Share

Save

Download

Download

## 14 Comments

Sort comments

Sort by

Top


Show featured comments


Newest


Show recent comments, including potential spam


![Default profile photo](https://yt3.ggpht.com/a/default-user=s48-c-k-c0x00ffffff-no-rj)

Add a comment...

![](https://yt3.ggpht.com/3utRF_NQhECSC2P7LWpA8QruUXRrORjgX5wgerYvLlAAtoYttCJDdAIR7XL8SVB7PhGXcGaarUU=s88-c-k-c0x00ffffff-no-rj)

### [@LanceWinder](https://www.youtube.com/@LanceWinder)

![](https://yt3.ggpht.com/Otv-LqYLhRy6jMTfXN_j8wo7dh0_UxEuAzGM8hhZLzoNdl16NRov8SqniPBUY90jnVMYlklKI0eHLLve=s32-k-nd)

[16 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgwtKLn5FWeR2r-XOs54AaABAg)

Love all this, thanks as always

Show lessRead more

Like

Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgwtKLn5FWeR2r-XOs54AaABAg.AUfNe2ry4kVAUfkNrEOavD&pp=0gcJCSIANpG00pGi)

Thanks so much! ![🙌](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f64c.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/ytc/AIdro_k8iHfGZwZtgAkYZjtGL67mObMMkHPukkAYLyWuXxJ5HuQ=s88-c-k-c0x00ffffff-no-rj)

### [@ShivanshSen7](https://www.youtube.com/@ShivanshSen7)

[21 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgwioGBtgFy6rRWE1094AaABAg)

I love the text version

Show lessRead more

Like

1


Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgwioGBtgFy6rRWE1094AaABAg.AUenB4nObAgAUfkUakLc2A)

Thanks so much, will do! ![🚀](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f680.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/ytc/AIdro_lxTZAaUbJ9c38MUPyYTZOl81VxQ-c5sevXCIT4bQ8nMJJb=s88-c-k-c0x00ffffff-no-rj)

### [@AndrewUnger-v4z](https://www.youtube.com/@AndrewUnger-v4z)

[23 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgxOLBYVldirLwv9acV4AaABAg)

love it

Show lessRead more

Like

Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgxOLBYVldirLwv9acV4AaABAg.AUeXAtQwgrNAUfkTEZGji_)

Thanks so much! ![🙌](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f64c.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/tGj38xjySfXMa3TFJx4hcu4QJm8CCt33aZU2yLet6XIBfwtUyl-X0OSSrsPQejOnRa-S8c3t=s88-c-k-c0x00ffffff-no-rj)

### [@io-shubh](https://www.youtube.com/@io-shubh)

[23 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgyYuq_8zsmvXqOKT7x4AaABAg&pp=0gcJCSIANpG00pGi)

So good , keep the series going on ![❤](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u2764.png)

Show lessRead more

Like

1


Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgyYuq_8zsmvXqOKT7x4AaABAg.AUebwqCorAsAUfkSVimA7p&pp=0gcJCSIANpG00pGi)

Thanks so much, will do! ![🚀](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f680.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/ytc/AIdro_nlLLXZRsGm74iObnc4BBv9qtr4AUhD792iHTyTZdLNvZZr=s88-c-k-c0x00ffffff-no-rj)

### [@wadahadlan](https://www.youtube.com/@wadahadlan)

[14 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgxMmsFHCnw13egC29V4AaABAg)

great series, easily becoming the best channel and the ai narration is consistent and fun, keep it up please, thanks as always

Show lessRead more

Like

1


Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgxMmsFHCnw13egC29V4AaABAg.AUfViJXffnKAUfkNIqkWd9&pp=0gcJCSIANpG00pGi)

Thank you so much ![😊](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f60a.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/ytc/AIdro_n6ZBBa_3wssvZ-3uYejR-pYif7bZ3F-sJr33JSyktwwYCCLRkkFCHIjZW7Up1yAzVU4w=s88-c-k-c0x00ffffff-no-rj)

### [@AlexT737](https://www.youtube.com/@AlexT737)

[23 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgywPlXojVrAshXUeQ94AaABAg&pp=0gcJCSIANpG00pGi)

Love the new series. Your videos are great, but would love to hear you narrate them directly :)

Show lessRead more

Like

1


Dislike

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

❤ by @GithubAwesome

Reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
Hide replies

![Github Awesome](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s48-c-k-c0x00ffffff-no-rj)

·
1 reply

![](https://yt3.ggpht.com/fgdG_4Y5n9M-49-enIA1R_Ot60eJXCceUxKXsgGjSbX240I1gr-Van1Ph78abWJfAL9rIlbRWQ=s88-c-k-c0x00ffffff-no-rj)

[@GithubAwesome\\
\\
\\
@GithubAwesome](https://www.youtube.com/@GithubAwesome)[12 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=UgywPlXojVrAshXUeQ94AaABAg.AUeZA2y-LFaAUfkR6YeYtW)

Thanks so much! ![🙌](https://www.youtube.com/s/gaming/emoji/7ff574f2/emoji_u1f64c.png)

Like

Dislike

Reply

Hide replies

![](https://yt3.ggpht.com/WqesnTjjXZksBMDCSG_R4NJPG2BqOsoYGpNDDjp-sefpnl10oZxvTEeeZ8Q045ER4rytvZ5PbLU=s88-c-k-c0x00ffffff-no-rj)

### [@donjon-intelligence-systems](https://www.youtube.com/@donjon-intelligence-systems)

[11 hours ago](https://www.youtube.com/watch?v=i9YpWp0hXgg&lc=Ugzi7UJNGSdVkKEUWHZ4AaABAg)

nobody else should be allowed to use this ai voice

Show lessRead more

Like

1


Dislike

Reply

Top is selected, so you'll see featured comments

## Comments14

Top


Show featured comments


Newest


Show recent comments, including potential spam


## In this video

Chapters

Transcript

Search transcript

### Chapter 1: Introduction

0:00

Today we're launching something new, the Hacker News show. Instead of our usual GitHub trending list, we're going straight to the show HN section, where

0:08

8 seconds

solo developers post the things they've been building. 30 projects handpicked from the archives. Let's get into it.

### Chapter 2: termcraft

0:16

16 seconds

Term is a fully playable 2D sandbox survival game that runs entirely in the terminal, written in Rust. procedural generation across the overworld, nether,

0:26

26 seconds

and end dimensions. Mining, crafting,

0:29

29 seconds

furnaces, hostile mobs, dungeons, all rendered in ASI directly in your console. If you spend most of your day in a terminal anyway, this is a

0:38

38 seconds

reasonable use of your lunch break. If you're running multiple clawed code sessions and losing track of which agent

### Chapter 3: Switchboard

0:45

45 seconds

is doing what, Switchboard is the missing layer. It's a desktop app built with Electron and SQLite that organizes all your CLI coding sessions by project,

0:55

55 seconds

gives you full text search across them,

0:58

58 seconds

and alerts you when an agent stalls and needs input. Less tab chaos, more visibility into what's actually running.

### Chapter 4: Fortransky

1:06

1 minute, 6 seconds

Someone built a fully functional terminal blue sky client in Forran. The fire hose decoder is Rust, but the core logic is modern forran. It landed on

1:15

1 minute, 15 seconds

hacker news and opened up a genuine conversation about how readable and performant modern forran actually is when people bother to look at it.

1:24

1 minute, 24 seconds

Keeping the old languages alive in the most unexpected places.

### Chapter 5: pi-worker-agents

1:30

1 minute, 30 seconds

PIWorker gives you autonomous agent workers that run natively in the terminal built for complex multi-step

1:36

1 minute, 36 seconds

pipelines. Handed a highle task and it handles execution in your local environment without you managing each

1:43

1 minute, 43 seconds

step manually. For anyone building serious AI automation pipelines worth checking the repository

### Chapter 6: Entroly

1:51

1 minute, 51 seconds

behind Entroly was burning 200 bucks a month just sending useless boilerplate code to their models. So they wrote a

1:59

1 minute, 59 seconds

context optimizer in Rust. Instead of dumping whole files into your prompt, it uses token budgeting and entropy scoring

2:07

2 minutes, 7 seconds

to strip out the junk before it even hits the API. It supposedly cuts token costs by almost 80% and adds less than 10 milliseconds of latency.

### Chapter 7: rsloop

2:18

2 minutes, 18 seconds

UV loop is the standard choice for speeding up async Python, but it doesn't run on Windows. RS loop does. It's a new

2:25

2 minutes, 25 seconds

Asyncio event loop written in Rust drop incompatible with existing code with strong P99 latency numbers for API

2:32

2 minutes, 32 seconds

servers and native Windows support out of the box. If you're running async Python backends on Windows and Uloop hasn't been an option, this is worth benchmarking.

### Chapter 8: GoldenMatch

2:44

2 minutes, 44 seconds

Entity resolution at scale is a genuinely hard problem. Golden Match makes it look straightforward. It uses a

2:51

2 minutes, 51 seconds

three- tier approach. Fast fuzzy logic handles the obvious matches and only the genuinely ambiguous edge cases get sent

2:58

2 minutes, 58 seconds

to GPT40 Mini as a tiebreaker. The result is 97% F1 accuracy on 100,000

3:05

3 minutes, 5 seconds

messy records in 13 seconds at a cost that amounts to pennies per run.

### Chapter 9: ps2-llm

3:11

3 minutes, 11 seconds

Someone ran a large language model on a PlayStation 2. The PS2 has 32 megabytes of RAM which is obviously nowhere near

3:19

3 minutes, 19 seconds

enough to load a model. The solution was a custom inference engine that streams weights directly from the CDROM drive matrix by matrix as needed. It's slow.

3:28

3 minutes, 28 seconds

It works. It absolutely did not need to exist and someone built it anyway.

### Chapter 10: Banish

3:34

3 minutes, 34 seconds

Writing complex state machines in Rust usually means deeply nested match statements that are hard to follow and harder to maintain. Banish is a

3:43

3 minutes, 43 seconds

procedural macro that lets you define states and transition rules declaratively instead. It uses a fixed point looping model where a state keeps

3:51

3 minutes, 51 seconds

re-evaluating its rules until nothing before moving on. Zero runtime overhead compiles down to pure rust.

### Chapter 11: batear

4:00

4 minutes

BATR is a drone detection system that runs on a $15 ESP32 microcontroller with a single microphone. It uses Gortzel

4:08

4 minutes, 8 seconds

filters to identify the specific audio harmonics of drone rotors. runs 247 on battery and triggers an alarm locally

4:16

4 minutes, 16 seconds

with no cloud connection involved for $15 in hardware and some open source firmware. That's a genuinely impressive capability.

### Chapter 12: Orchestrator

4:25

4 minutes, 25 seconds

Orchestrator gives you a T-m style split pane terminal dashboard for running multiple clawed sessions simultaneously.

4:33

4 minutes, 33 seconds

Instead of managing agents one at a time, you get a unified interface for assigning tasks across a coordinated swarm, all visible in one place.

4:42

4 minutes, 42 seconds

For anyone who's wanted to run parallel agents without the tab chaos, this is the direct solution.

### Chapter 13: QueryPad

4:49

4 minutes, 49 seconds

Opening Python or a spreadsheet app just to check a column in a large CSV is one of those small annoyances that adds up

4:56

4 minutes, 56 seconds

fast. Queryad is a browserbased SQL playground powered by Duct DB. Drop in a CSV, JSON or parquet file and run SQL

5:05

5 minutes, 5 seconds

queries against it directly in the browser. Nothing uploads anywhere.

5:09

5 minutes, 9 seconds

Everything processes locally and duct DB handles gigabytes without breaking a sweat.

### Chapter 14: Inner Warden

5:15

5 minutes, 15 seconds

Inner warden is a self-hosted security agent for Linux and Mac OS written in Rust. It uses ebpf kernel programs to

5:23

5 minutes, 23 seconds

block attacks at wire speed, detects privilege escalation in real time, and deploys honeypots to misdirect attackers. No cloud dependencies, no

5:31

5 minutes, 31 seconds

data leaving the machine. Your server handling its own defense locally is a meaningful shift from alert and respond.

### Chapter 15: NC Web

5:39

5 minutes, 39 seconds

Someone saw a screenshot of Norton Commander and immediately rebuilt it in vanilla JavaScript for the browser. Dual pane layout, iconic blue interface, FY

5:49

5 minutes, 49 seconds

toolbar, the whole thing. It uses the Origin private file system API for actual file management. So, it's not

5:55

5 minutes, 55 seconds

just a visual gag. Pure90s nostalgia that actually works in 2026.

### Chapter 16: filenotes.nvim

6:02

6 minutes, 2 seconds

FileNotes.nenvim opens a floating markdown scratchpad tied to whatever file you're currently editing in Neoim.

6:09

6 minutes, 9 seconds

It hashes the file path and saves the note to a hidden.notes folder at the project route, so your context and reminders stay organized without touching the actual code. Small plug-in,

6:20

6 minutes, 20 seconds

genuine quality of life improvement for anyone who leaves themselves notes in comments.

### Chapter 17: AI SDLC Scaffold

6:27

6 minutes, 27 seconds

Most AI coding sessions skip straight to implementation.

6:31

6 minutes, 31 seconds

The planning phase gets ignored and the architecture suffers for it. AI SDLC scaffold is a template repository that

6:38

6 minutes, 38 seconds

forces the pre-work. Structured markdown scaffolding for user stories,

6:42

6 minutes, 42 seconds

architecture decisions, and requirements designed specifically to make your agent plan the system before writing any code.

### Chapter 18: capit

6:51

6 minutes, 51 seconds

Running autonomous agents without spend limits is a reasonable way to return from lunch to a $50 API bill. Capit sits

6:59

6 minutes, 59 seconds

between your agents and your LLM providers, enforcing hard-coded budgets per agent and per provider. If something

7:07

7 minutes, 7 seconds

goes rogue or gets stuck in a loop, it cuts off before the damage compounds. For anyone running agents unattended,

7:13

7 minutes, 13 seconds

this should probably be in the stack already.

### Chapter 19: MakhalReader

7:17

7 minutes, 17 seconds

500 unread RSS items every morning is not a reading habit. It's a backlog.

7:22

7 minutes, 22 seconds

Macall reader parses full text feeds and runs every article through a local LLM like Olama, scoring each one from 1 to 10 based on your actual interests.

7:31

7 minutes, 31 seconds

Clickbait listical sync high signal engineering posts surface. The tagline is an RSS reader that thinks before you do. Hard to argue with that.

### Chapter 20: VideoZero Skills

7:42

7 minutes, 42 seconds

Most AI agents can write code. Video zero skills lets them animate it. It's a toolkit of agentic skills built

7:50

7 minutes, 50 seconds

specifically to give AI coding agents programmatic control over the motion canvas engine. Your agent can write the animation code, render text and shapes,

7:59

7 minutes, 59 seconds

and output finished code visualization videos without any manual intervention.

### Chapter 21: woti

8:05

8 minutes, 5 seconds

Scheduling across five time zones usually means opening three different websites and doing mental arithmetic.

8:11

8 minutes, 11 seconds

Wii is a terminal UI built in Rust that shows an interactive timeline of multiple time zones side by side. Scrub

8:19

8 minutes, 19 seconds

forward and backward to find the overlap window where everyone is actually awake.

8:24

8 minutes, 24 seconds

Fast, local, and solves the problem without leaving the terminal.

### Chapter 22: elastik

8:29

8 minutes, 29 seconds

Elastic rethinks the AI agent and web interaction problem in under 200 lines of code. Instead of building a complex

8:37

8 minutes, 37 seconds

agentic UI, it treats the LLM purely as an untrusted HTTP client using the model context protocol, forcing it to interact

8:45

8 minutes, 45 seconds

with a database, HTML front end, and server through a properly isolated sandbox. It's a clean demonstration of

8:52

8 minutes, 52 seconds

applying web security principles to AI architecture.

### Chapter 23: react-container-kit

8:56

8 minutes, 56 seconds

Context provider boilerplate is one of those things every React project reinvents slightly differently. React container kit is a lightweight utility

9:04

9 minutes, 4 seconds

layer on top of unstated next that gives you named containers, clean provider composition and TypeScript helpers out

9:11

9 minutes, 11 seconds

of the box. Write it once, stop rewriting it everywhere. Small library,

9:17

9 minutes, 17 seconds

real reduction in friction across projects.

### Chapter 24: agent-password

9:20

9 minutes, 20 seconds

Hard- coding API keys for local AI agents is an obvious security problem with no great solution until now. Agent

9:28

9 minutes, 28 seconds

password is a local Mac OS password manager built specifically for AI workflows. Secrets live in an encrypted SQLite vault and when an agent needs

9:37

9 minutes, 37 seconds

one, it requests access through Touch ID. Tap your fingerprint, the agent gets the key. Nothing sits in plain text.

### Chapter 25: Nya AI

9:45

9 minutes, 45 seconds

Nia AI is an open-source collaborative platform that puts AI chat, team workspaces, rich text pages, cloud

9:52

9 minutes, 52 seconds

storage, and channels in one place. The practical difference from just using chat GPT alongside your other tools. The AI can actually read your team's files

10:01

10 minutes, 1 second

and operate inside documents rather than existing in a separate tab you copy paste between.

### Chapter 26: Collo.dev

10:08

10 minutes, 8 seconds

AI scrum master template turns a GitHub repo into a self-managing development pipeline using GitHub actions and

10:15

10 minutes, 15 seconds

claude. A scrum master agent reads feature requests, breaks them into canban tickets, and routes them to separate planner, developer, and tester

10:24

10 minutes, 24 seconds

agents. The whole thing runs inside your existing issue tracker without any additional infrastructure.

### Chapter 27: Rover

10:32

10 minutes, 32 seconds

Most support chatbots answer questions.

10:34

10 minutes, 34 seconds

Rover just does the thing for you. Drop a single script tag into your web app and it embeds a live AI agent directly

10:41

10 minutes, 41 seconds

in the UI. Tell it to help you check out and it takes over the DOM, navigates the page, clicks buttons, and fills out

10:49

10 minutes, 49 seconds

forms in real time. The gap between here's a help article and I'll do it for you is significant. Rover sits firmly on

10:56

10 minutes, 56 seconds

the useful side of it. Pomodoro works for some people. For everyone else, the 25minut cut off hits right in the middle

### Chapter 28: CYCLE

11:05

11 minutes, 5 seconds

of actual focus. Cycle flips it. Work for as long as you're genuinely in flow.

11:10

11 minutes, 10 seconds

Hit stop when you're done and it calculates a proportional rest break based on how long you actually worked.

11:16

11 minutes, 16 seconds

No arbitrary timer cutting you off. No guilt about going over. Simple idea, surprisingly well executed.

### Chapter 29: OpenHarness

11:24

11 minutes, 24 seconds

If the official anthropic and OpenAI SDKs feel like too much framework for what you're actually trying to build,

11:30

11 minutes, 30 seconds

Open Harness is worth a look. It's a TypeScript library on top of Versel's AI SDK that gives you composable building blocks for agentic workflows without the overhead.

11:40

11 minutes, 40 seconds

supports the agents.mmd spec, sub aent delegation, and autocompaction for long conversations out of the box.

### Chapter 30: sift

11:49

11 minutes, 49 seconds

A failing test suite that dumps 13,000 lines of logs into your agents context is an expensive problem most people are

11:56

11 minutes, 56 seconds

just absorbing. SIFT sits between your terminal and your agent, captures the output, groups repeated failures, and

12:05

12 minutes, 5 seconds

compresses it into a structured diagnosis. 200,000 tokens of raw logs down to 120 without losing the actual

12:12

12 minutes, 12 seconds

debug signal. The kind of tool that pays for itself immediately.

### Chapter 31: Skill Lab

12:18

12 minutes, 18 seconds

Writing agent skills is easy. Writing agent skills that actually trigger correctly is a different problem. Skill

12:24

12 minutes, 24 seconds

Lab is a Python CLI tool that runs 19 static checks on your skill.md files,

12:30

12 minutes, 30 seconds

validating structure, naming, and descriptions. It statically links your skill files, which is fine. But the second half is what actually sold me. It

12:39

12 minutes, 39 seconds

uses Claude to autogenerate brutal edgecase prompts, then tests them against a live model to prove your skill actually activates in context.

Sync to video time

## Chapters

[**Introduction**  **Introduction** \\
\\
0:00](https://www.youtube.com/watch?v=i9YpWp0hXgg)

[**Introduction**](https://www.youtube.com/watch?v=i9YpWp0hXgg)

0:00

[**termcraft**  **termcraft** \\
\\
0:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

[**termcraft**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

0:16

[**Switchboard**  **Switchboard** \\
\\
0:41](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

[**Switchboard**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

0:41

[**Fortransky**  **Fortransky** \\
\\
1:06](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

[**Fortransky**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

1:06

[**pi-worker-agents**  **pi-worker-agents** \\
\\
1:30](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=90s)

[**pi-worker-agents**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=90s)

1:30

[**Entroly**  **Entroly** \\
\\
1:51](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=111s)

[**Entroly**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=111s)

1:51

[**rsloop**  **rsloop** \\
\\
2:18](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=138s)

[**rsloop**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=138s)

2:18

[**GoldenMatch**  **GoldenMatch** \\
\\
2:44](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=164s)

[**GoldenMatch**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=164s)

2:44

[**ps2-llm**  **ps2-llm** \\
\\
3:11](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=191s)

[**ps2-llm**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=191s)

3:11

[**Banish**  **Banish** \\
\\
3:34](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=214s)

[**Banish**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=214s)

3:34

[**batear**  **batear** \\
\\
4:00](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=240s)

[**batear**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=240s)

4:00

[**Orchestrator**  **Orchestrator** \\
\\
4:25](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=265s)

[**Orchestrator**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=265s)

4:25

[**QueryPad**  **QueryPad** \\
\\
4:49](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=289s)

[**QueryPad**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=289s)

4:49

[**Inner Warden**  **Inner Warden** \\
\\
5:15](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=315s)

[**Inner Warden**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=315s)

5:15

[**NC Web**  **NC Web** \\
\\
5:39](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=339s)

[**NC Web**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=339s)

5:39

[**filenotes.nvim**  **filenotes.nvim** \\
\\
6:02](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=362s)

[**filenotes.nvim**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=362s)

6:02

[**AI SDLC Scaffold**  **AI SDLC Scaffold** \\
\\
6:27](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=387s)

[**AI SDLC Scaffold**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=387s)

6:27

[**capit**  **capit** \\
\\
6:51](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=411s)

[**capit**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=411s)

6:51

[**MakhalReader**  **MakhalReader** \\
\\
7:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=436s)

[**MakhalReader**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=436s)

7:16

[**VideoZero Skills**  **VideoZero Skills** \\
\\
7:42](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=462s)

[**VideoZero Skills**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=462s)

7:42

[**woti**  **woti** \\
\\
8:05](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=485s)

[**woti**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=485s)

8:05

[**elastik**  **elastik** \\
\\
8:29](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=509s)

[**elastik**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=509s)

8:29

[**react-container-kit**  **react-container-kit** \\
\\
8:56](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=536s)

[**react-container-kit**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=536s)

8:56

[**agent-password**  **agent-password** \\
\\
9:20](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=560s)

[**agent-password**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=560s)

9:20

[**Nya AI**  **Nya AI** \\
\\
9:45](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=585s)

[**Nya AI**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=585s)

9:45

[**Collo.dev**  **Collo.dev** \\
\\
10:08](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=608s&pp=0gcJCeACDuyUWbzu)

[**Collo.dev**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=608s&pp=0gcJCeACDuyUWbzu)

10:08

[**Rover**  **Rover** \\
\\
10:31](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=631s&pp=0gcJCeACDuyUWbzu)

[**Rover**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=631s&pp=0gcJCeACDuyUWbzu)

10:31

[**CYCLE**  **CYCLE** \\
\\
10:59](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=659s)

[**CYCLE**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=659s)

10:59

[**OpenHarness**  **OpenHarness** \\
\\
11:24](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=684s)

[**OpenHarness**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=684s)

11:24

[**sift**  **sift** \\
\\
11:49](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=709s)

[**sift**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=709s)

11:49

[**Skill Lab**  **Skill Lab** \\
\\
12:18](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=738s)

[**Skill Lab**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=738s)

12:18

Sync to video time

## Description

Hacker News Show #1: termcraft, Switchboard, Fortransky, Entroly, rsloop, GoldenMatch, Banish, capit

109Likes

3,630Views

Mar 222026

Today we're launching something new: the Hacker News Show. Instead of our usual GitHub trending list, we're going straight to the Show HN section, where solo developers post the things they've been building. Thirty projects, hand-picked from the archives.

Paid channel subscription: [/ @githubawesome](https://www.youtube.com/channel/UC9Rrud-8CaHokDtK9FszvRg/join)

Text version link:[https://githubawesome.com/hacker-news...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbjlVTEtNZTNjbHd6NlEzbDM2N0VEY2ZpNjJQZ3xBQ3Jtc0tuazlHN1dQUTJkY2pkcExtb2xnTkdsS1ltNlRCT3N5UnFFcWFyaUpKUUd6RTZuQWdXWjh6QkJwN2xLZnRQblUzWU95SXE4bUlBQlUyd0FIdmtqSWJyME5wVGRNdmxFa1czcEM3ZllpcEMwM2cyOGgyTQ&q=https%3A%2F%2Fgithubawesome.com%2Fhacker-news-show-1%2F&v=i9YpWp0hXgg)[00:00](https://www.youtube.com/watch?v=i9YpWp0hXgg) \- Introduction
[00:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s) \- termcraft [https://github.com/pagel-s/termcraft](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbWFHTW90RHJXYk03eWVwT3lhZkVBQ0lqVTVyZ3xBQ3Jtc0ttellPajN5V09JakxhSEQ3U1VSejY4R3NnVWFvMUxCWWFwZjZ3Nkg1YmlGTGR0WU1kU2M4OTM5dDY5VW5lWDlRdHZER1BWNUpORzFLNjlRMHNZdFhYcnRkXzlSTmhIU2ZxN0JSRGpJSFh0d2JWMTVpcw&q=https%3A%2F%2Fgithub.com%2Fpagel-s%2Ftermcraft&v=i9YpWp0hXgg)[00:41](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s) \- Switchboard [https://github.com/doctly/switchboard](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbG5rZXBYWUhjSGhCMGVyRTczRHpjSTZTbU5tQXxBQ3Jtc0ttTTNPVDFpSFY2NWJZRXVWSEdONFkzYmtHQnY2SF9mcjlNMm1RY3pVZ3JPcXRmeHplQWtDNU5GQWlNaXlqYUNTMlJvTzV3Mm40Y0F0Sl9TbUxqblR5VDQ1SmQ5NUZMTVUxelVJYmRyZ0VLOXRjYnNVcw&q=https%3A%2F%2Fgithub.com%2Fdoctly%2Fswitchboard&v=i9YpWp0hXgg)[01:06](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s) \- Fortransky [https://github.com/FormerLab/fortransky](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbDF6NkgzUmNXZG13OEdZOE8tRGkwQUdrSWZJZ3xBQ3Jtc0tuTUZUdlJkc1p6bl9aekp6NXNFR3Iyc1hxYXpZbU9wRTdjYWl1SE9oSXBVVzFqc2k4cnZuZEpHMWVyQzR6ZFVjaHptd19RdU55VkFacWgyT04xUG01LTdTSVdaMENfdUo4em9XZ045LTR5MWV0YWphUQ&q=https%3A%2F%2Fgithub.com%2FFormerLab%2Ffortransky&v=i9YpWp0hXgg)[01:30](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=90s) \- pi-worker-agents [https://github.com/qaml-ai/pi-worker](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbFFFSm9hMlgyRXlrTWMtX0FMMDlWbWFqeVFFZ3xBQ3Jtc0treHlQejdoQzJuY3hMejc3YUJYRGFtemc1a0ZJUGQ3dThIcTFFQktQck0tazZoX0o0cG9uaVo2OUxJdnJRQVl0X29qaUVFdHlnNzk2N2xzZ1E0dTZrd2drQktPekZYcUMwMXpNRTVKZm9wc3dvajdFNA&q=https%3A%2F%2Fgithub.com%2Fqaml-ai%2Fpi-worker&v=i9YpWp0hXgg)[01:51](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=111s) \- Entroly [https://github.com/juyterman1000/entroly](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbmhqeUd0OXNycG1qZGZHcTVtNGxWbURGbkpPQXxBQ3Jtc0tuMHUtalZzWVpMVGMzR20zck41YlA3MGVhMFFyWVF1ZUtiRUlST1UyWG8yMGQ0ZEhnY0UzTEFGZDVvazRzaTVxOEt5WFRhTjNyMU9RVXc0eE1RQ183X1gyRXJpbWhQbXhJampkUXdNU2RaUG9KLUdvcw&q=https%3A%2F%2Fgithub.com%2Fjuyterman1000%2Fentroly&v=i9YpWp0hXgg)[02:18](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=138s) \- rsloop [https://github.com/RustedBytes/rsloop](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbVIzcFU4UGJjb2IxMHNKaXAyY3hfZ1FFR00tZ3xBQ3Jtc0ttWU5WSFA5Z2RGZTNPcWhISlEzd25SNVA0NEk0THljbXVKWm54eHpjYXNWWVhSQ1hYMFpmMnFDOE5TV2ExYXl6cTlTQ0xmRjBPellDTVFMNVQ4bEpRNTZ3XzEwMmxvbGdEaEl2cE9qZGllbnM4cG0zZw&q=https%3A%2F%2Fgithub.com%2FRustedBytes%2Frsloop&v=i9YpWp0hXgg)[02:44](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=164s) \- GoldenMatch [https://github.com/benzsevern/goldenm...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbkdydG5zVXdQQmlJb3JuM21BRXMzYTRFdDlLZ3xBQ3Jtc0tuNWxrd2d2cnBHUWJ3QzRMd2dOVDhrdFlZbjNNd2ZRMk1hQjZrSXNuNkdTdU5UeFZqS3ZFeDd1bVI3UVZSS2oxR0NxSE1kWk1lTkhiV1prRWgzelduVjJoa0hpNGFIeXVmaWhxYURqY0dOU29NdVJYOA&q=https%3A%2F%2Fgithub.com%2Fbenzsevern%2Fgoldenmatch&v=i9YpWp0hXgg)[03:11](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=191s) \- ps2-llm [https://github.com/xaskasdf/ps2-llm](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbDYwS2hzU2tSUXBqSW9KQXl3MTdfQV92dGFiZ3xBQ3Jtc0ttZGJMVG5DeFJLWWFyYUNabllXY2hnZ0ZjaVRHV3ozNDRNTGh2N2Izb1FMZTdRb0NsYmVXalFtWURGdVF6OGF6NWpIVm5nY00ySDZRUkduNHpNRkoxeUF5cDRSNnNxOWdtNUhJS0oxU3liYVJwVTdGRQ&q=https%3A%2F%2Fgithub.com%2Fxaskasdf%2Fps2-llm&v=i9YpWp0hXgg)[03:34](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=214s) \- Banish [https://github.com/LoganFlaherty/banish](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbmJQRmVfSmtQZlpZbWZZRG5BUnJiSTZTUUpJQXxBQ3Jtc0trbVh6OWNFdUFsUUp2d2p6V0NtUy03aVA3TDZjTlZ2U2ZrZkoyalVLSFdfY0ZqZFdlVDVVU1dBMWplR2hsNW5iWjUxRV9hdjBUZmFMbk13dGNmYnZHWUJBRFQycWpCOTBqMTdnN212LXZHQjZSS1Y1bw&q=https%3A%2F%2Fgithub.com%2FLoganFlaherty%2Fbanish&v=i9YpWp0hXgg)[04:00](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=240s) \- batear [https://github.com/TN666/batear](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbDROTHZ4V1VLMVJwSGFpWWYtOGlUZDVYWFpPQXxBQ3Jtc0ttYnJwVkNRZ25JMmlGSlZPZzdGV0htTktQbXhNa0FyLWxkb005TWVCX0QtcjRnS1NnSG1rTUY4WS1iZ25CLUMzUnRTbjZvRFNtWkxkOGxoTDBET0FJcmtZSVBHSUxwQWdYNlNVRDVDeHo4bnhHZmZJRQ&q=https%3A%2F%2Fgithub.com%2FTN666%2Fbatear&v=i9YpWp0hXgg)[04:25](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=265s) \- Orchestrator [https://github.com/MatchaOnMuffins/or...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbXAzcHdLT3E5WFNSeUxsRGpRak9ncnBMRi1EZ3xBQ3Jtc0ttZTY1a2ZUWHVqdGxxaExWLWdKMzZhLVRvaC14VGdkWVlCMzF1d2FaaGQ1dEtJRTM2TElTUlNaYzYxSVZvRUpfeG9WdkY2QTNaZ3BtWHFHV1hjSE5OUzV4by1oR2RuVWdzV04zeTdRTUxTZDBUbFZBTQ&q=https%3A%2F%2Fgithub.com%2FMatchaOnMuffins%2Forchestrator&v=i9YpWp0hXgg)[04:49](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=289s) \- QueryPad [https://github.com/vericontext/querypad](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbC1Za3RkUjdTNHI4QVVkSURSWWNrOGEycDFWQXxBQ3Jtc0tscXZqRm5PS2tyZWpEcUEzWUxlcVNQNlp0TDhsdVNnallReElCT2FteGFEOElsNTRZZzRmU0lvbGE2Q3BCZVNwMHYyZ1RCSnRqMUUzMnZqRWl1X0lhaWJMTGZTUS05eVhWeWZXVXR0dDRYNVJRZVNFTQ&q=https%3A%2F%2Fgithub.com%2Fvericontext%2Fquerypad&v=i9YpWp0hXgg)[05:15](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=315s) \- Inner Warden [https://github.com/InnerWarden/innerw...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqazEwUGZsRVlZeU96V2ZRZmY2T0loM1JKMlpjZ3xBQ3Jtc0tuVUhzNmJBcjU1TzhyMDF5M0VtQmhORWl3MXlHN1luZ2hTZ2h2NjZiM0NGWGNFcXRaN043dE1vXy1NdkFLX285THRLZ0xLWVNIbWQ2XzBzTHRUNlNXbkdPLTRmSGJiUlAyQ2V4SEVCa3J6cmYzcTNjUQ&q=https%3A%2F%2Fgithub.com%2FInnerWarden%2Finnerwarden&v=i9YpWp0hXgg)[05:39](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=339s) \- NC Web [https://github.com/victorantos/NC](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbGxSa3Q0bkt1Sml4LTlmMVRaTTU5MGFxdTFCQXxBQ3Jtc0trV1RaRFZzVm8zUlBEbEJzX3loMmEzSVZKQ0VFQWJPUk1oUDJpMHAwdXEwd1hHU09aWHIzNzFCZlZTcnJUMzVvcnZwRl85MF9KaXBxUEdidG1MNlZ0dVROVFEwa1ZmSnNkOENhNkRUaHRmUW9hMVVHMA&q=https%3A%2F%2Fgithub.com%2Fvictorantos%2FNC&v=i9YpWp0hXgg)[06:02](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=362s) \- filenotes.nvim [https://github.com/UsamaQaisrani/file...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbi1ud1ROS0kycG9MTFZCNWUwQ21LeURDOG9hZ3xBQ3Jtc0tudUpMQjRzUVA4UVZtNU56NnRITENxMkhSMlFZanhwd0V0Z3dxUXNJdUtwQ1JFaFo0VkxNTVJSQV8zRzd3a0REQW9lMHcwMkdGLVdUTUpRcjFmd3hMamhmbGhhYVhaMzlqaHdhV1c1ZjNLeV9BdlJ6WQ&q=https%3A%2F%2Fgithub.com%2FUsamaQaisrani%2Ffilenotes.nvim&v=i9YpWp0hXgg)[06:27](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=387s) \- AI SDLC Scaffold [https://github.com/pangon/ai-sdlc-sca...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbC1NdE53ZG5lWXlrdkJ1MlNqMVd1R0haX2hOQXxBQ3Jtc0trdWFoNVVhQzVLWlRBVk8yUUpPeVhzVm5KOHRQQ1RGZFFFa2NkWHljWFJ5aTFCczg1TWw4T19wS2pLWFh2bXNCVHRPRUN5dWJYNml4V0s2dzJUMzRVOWhzTE0ySHNEUTdZTkN4Ynk1czZ0UWRjV1hDZw&q=https%3A%2F%2Fgithub.com%2Fpangon%2Fai-sdlc-scaffold&v=i9YpWp0hXgg)[06:51](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=411s) \- capit [https://github.com/day50-dev/capit](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqa0ZkRXR2U20ybHFIOUFOWHJKRnJBdEtPclpNUXxBQ3Jtc0ttYjJpdjhpbjJGbktYbU9mcEdXVzlxR2ZCWksxLXd5S0s5V2F0QWVtdW92dWhJWW1VT3U2RGYxZkNzVEd3QzQ3TE5MdkJKVjV5Q3FieGZycnl5VDhxdXRWM0Joc2JvdXJzNzFjWE55Tk4tdzlJYUk0UQ&q=https%3A%2F%2Fgithub.com%2Fday50-dev%2Fcapit&v=i9YpWp0hXgg)[07:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=436s) \- MakhalReader [https://github.com/Tutanka01/makhalRe...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbEtwUjNDX2xabFhPbnR5NS1pRkxzaEtDVUVhUXxBQ3Jtc0tsU2pLRzNMdE44ZkVDYUJQdHJIcDV2aWJPNVItQldMa1ZUdWd0S2tsVkhCMGt3Ui1yVVJORFFudngtMWdDUlhLU3d0Tnc4QUJkRGZHNFJOYXFTWWJKRjJyalMyeXpiZDdGUGQ3Z0xVbGFRQzFUXzZxSQ&q=https%3A%2F%2Fgithub.com%2FTutanka01%2FmakhalReader&v=i9YpWp0hXgg)[07:42](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=462s) \- VideoZero Skills [https://github.com/VideoZero/skills](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbTVEMENWNnlVNGxDRFhkZ3JDSTZ5Q3lyVGZid3xBQ3Jtc0trX0Z2ZllabVZYY0NLZXNpRFJOekhPNlBjNmxvMkJxQTdYUFpvczg3S0c2cERmSmZYUUlzSlUzUDlEay1DTlRhWmt6WVQ5eFo2QzROdHZTWUQ2cTNpeE12NlAtSDI1RE01WFlSN3lVRERDOUtiS3pXVQ&q=https%3A%2F%2Fgithub.com%2FVideoZero%2Fskills&v=i9YpWp0hXgg)[08:05](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=485s) \- woti [https://github.com/aleris/woti](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbEJlaHlSSHY5a0VpS3JfTHh2TDg2ZllnbEFkZ3xBQ3Jtc0traWVKZ1NGVDBIU0FrbGd6QWNwQUg5bTVXV0dkTjY4T3BPVTFGcXBUZE9HRGFoQXJZcUNCd0ZrVnplODZtNTJxbEFiYXRzcUdldUhvUUwtX0JDZ256bUpTS2o5d2NVdVVRWlloZ2lQNDZSMXpSc3RMaw&q=https%3A%2F%2Fgithub.com%2Faleris%2Fwoti&v=i9YpWp0hXgg)[08:29](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=509s) \- elastik [https://github.com/rangersui/Elastik](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqazRhYWdvbmV5dzliemJHVk90Znd3Z1l0RUU2Z3xBQ3Jtc0tuQ2NoQ1FMNko2TzgzR2NQLUZEOTR2MmRNZmVoUUpGQUxOYXVUSU5PSi1XS3dMU0hYSjUxWnNxTkxjRnVVci1NOFlCRjFlUWxSWDRfR1p4WjBKYUZvNklWdk92dVR6Y1huX3czRV91c1h3S1dMc1B0UQ&q=https%3A%2F%2Fgithub.com%2Frangersui%2FElastik&v=i9YpWp0hXgg)[08:56](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=536s) \- react-container-kit [https://github.com/harveyrandall/reac...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbU43ZzN6QVE1M3ZvWnhCOE1odWltTGgyVlU0d3xBQ3Jtc0tuLVQyTjZPSjFBUnNDUlpqNGJHWUhERlhxWkVpNk45d2pSOTAxYWFWMEFRcllSLVNvcjd1Q0hsaU1LTmZaSi1GWlZOaGpfTFBoN2lTN1UwY3ZCU1Jjb0ZOU3hPTFdQa0V1dFRGaWRuUVByQUxSM20tcw&q=https%3A%2F%2Fgithub.com%2Fharveyrandall%2Freact-container-kit&v=i9YpWp0hXgg)[09:20](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=560s) \- agent-password [https://github.com/tartavull/agent-pa...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqazI4cGdnbURxVnNLX25SY1UyMkprYnBPdVhHQXxBQ3Jtc0ttYThDYlo1WlpwdDh2ZWpLMFdzSlpTalFIcFdhZmxXajBqQ25WOG5nV0RnOUR2czEyazF1MnI3MkdzajZaVWR3SWFLeWU1eWF4YkhmeDZDcy1xajBKNkF0V2JjcThHaE91amNVUDJ6TWtGaWhEdUNSbw&q=https%3A%2F%2Fgithub.com%2Ftartavull%2Fagent-password&v=i9YpWp0hXgg)[09:45](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=585s) \- Nya AI [https://github.com/NitroRCr/nyaai](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbWRONDlvWEUxajVaVFpJNWZXeVJqMjYtcGlJZ3xBQ3Jtc0trZ0JTV0t1cGxjMzdMQmRLVzZidUtfVElkcFpQUEtlV1JaZFVpam5aZ1J4VllkTEpqcjl5VmRXN2o2LXNCaklrSnhqaVJIQUhKQ09wU1FSZHZaYWxsRENuUy1DdjRseFRvVnpiYTVnMXVwY053VVl1QQ&q=https%3A%2F%2Fgithub.com%2FNitroRCr%2Fnyaai&v=i9YpWp0hXgg)[10:08](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=608s) \- Collo.dev [https://github.com/plusai-solutions/a...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbFJNV0F3OGROalpyd2V0ZUdxOGZEaUpNeEhjZ3xBQ3Jtc0tuQjAycnZFbUFlMGF0cTh6RGVSUF8xajhEaE13QmtHcjhMdkdGTXF0UWIwSFlWUlhWN1FTS0F2WWhtSjg2R3EzNXg1YUhGNXIyUUlSNENSalhGUHRYdUFSbnJBM1FzaVZpOXJnNmk4QlZ3azR2WWJ4Yw&q=https%3A%2F%2Fgithub.com%2Fplusai-solutions%2Fai-scrum-master-template&v=i9YpWp0hXgg)[10:31](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=631s) \- Rover [https://github.com/rtrvr-ai/rover](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbUVIUHlXeGlyNzk2RlRKbWh1U1k3eU01RFV4Z3xBQ3Jtc0tsOUJOYTRVMmdYU3pYRXJoTm1QODZaLUxWLV9BdGI2ZXJ5TXNPTWFTWHBVT0VES0xCNzRiVTdHeVkyakkyOHdSOXc0SFhrcjFCR2I2X1dxTkFjSUFPdUZxRDlvZnpyam1xdFZGM2NwYW5Ld2M2a1dOYw&q=https%3A%2F%2Fgithub.com%2Frtrvr-ai%2Frover&v=i9YpWp0hXgg)[10:59](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=659s) \- CYCLE [https://github.com/saint-angels/CYCLE](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbkljSktfSVJMa2RsTFV0RmR5NDd2UktHajVHUXxBQ3Jtc0trSHgyQU1YTlRMUnRNLXRNNmQzNE9qeXRoOEkzalhYN0JOYWhBVlRwSllQM25sdWVyaFNISXV3LUNJU21DSl9jbXYyQ09XTUY3NHNsMmZ1RFpkVU9tV0ktaTNudGNQTExKOFhZYy1kQWJFS3VEVTUwZw&q=https%3A%2F%2Fgithub.com%2Fsaint-angels%2FCYCLE&v=i9YpWp0hXgg)[11:24](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=684s) \- OpenHarness [https://github.com/MaxGfeller/open-ha...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbGVvcHJGMHYyek1rMFdXZkRQVVpZdWtVZWcxd3xBQ3Jtc0trS1p0Mm00Y1dCVzU1STNtdUptbzgxYW1tejZiLV92cGcta0c2eFN0Y3gyY0hpcTJfNVRPVTdhM0ZramViSmJIRnVkbThtNWxNdDl6RG1VYlUtVGJQUXBqek1xdktTZ2MtWVVnYW45eWdVSmVFQW1PQQ&q=https%3A%2F%2Fgithub.com%2FMaxGfeller%2Fopen-harness&v=i9YpWp0hXgg)[11:49](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=709s) \- sift [https://github.com/bilalimamoglu/sift](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbFRnSEJlUGUwSzVOaXZjTktfd2dNYmNydC1Sd3xBQ3Jtc0tsOFpHTXJlX01hUk9udlRVT01yWTZManFsajVIZFpqQkNtcFJ3MldDQVB1UTFKQ1FGTnQybExMRVh2bV9Ib3ZQZV80M3cwNXNWdWs1U0t6RzJ6RU5DbzVqZVZPMXZ0Tk5CQTR0Zk01S2VDYURSUnBIMA&q=https%3A%2F%2Fgithub.com%2Fbilalimamoglu%2Fsift&v=i9YpWp0hXgg)[12:18](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=738s) \- Skill Lab [https://github.com/8ddieHu0314/Skill-Lab](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbmJfU0VGenQzZ1RZbmRoOFdiS0Vlc3pfcVQ1Z3xBQ3Jtc0tsNVVqcHZoVTE0ZHZJYjN0OWZHcGhNanplMGZmemo3dzJ2cU1yMDkxWGNTSmpvWkhDS21QM1JXamVSZHMwQ254QmVZaE13bVlkV3AtRENKSlpZeGxBVjFCQklyQnZlOEluVzduaUREZ0tTakZjMVc4VQ&q=https%3A%2F%2Fgithub.com%2F8ddieHu0314%2FSkill-Lab&v=i9YpWp0hXgg)

Thank you so much for watching. Please like the video and subscribe to our channel.

[#github](https://www.youtube.com/hashtag/github)[#ai](https://www.youtube.com/hashtag/ai)[#opensource](https://www.youtube.com/hashtag/opensource)

▬▬▬▬▬▬ 👋 Contact me 👋 ▬▬▬▬▬▬
➡ LinkTree: [https://link.githubawesome.com/linktree](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbS1pYUh6ZmZkU1NkWFMybzhGcGE5QW9hMmNrZ3xBQ3Jtc0tudG4yOG1kZGJscXNyMF9WdUZwNEtfeGZGMThrZGduNUdBMVFkRW83YUpNSXcxQkY1RFVRNW50RTdOdHZJX1FidE5aVjc5aFpLVlo2bFZveXNjTnliTWtweXdHUVVMMF9XdGJwTkdFT2ZXUG1qUXlFMA&q=https%3A%2F%2Flink.githubawesome.com%2Flinktree&v=i9YpWp0hXgg)
➡ Threads: [https://link.githubawesome.com/threads](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbjVWblRGOW1CdWE2TDRoUGVIRGRfTEpzUzBOZ3xBQ3Jtc0tsM0N3Y0tpcnRoS3p0emQ2UXhBTlZJMWJGZm15UTBPSnlQWWxPTmpsRHNvM3ZVdkdrNWtvbldPYVFyc0s5WFpXRkw0aW1KQnQ0UzNCcmFBWXJoZUxXcHZ4MFFWSGpNSFJNaUJYMXJMbno5ZWQ1RDVqMA&q=https%3A%2F%2Flink.githubawesome.com%2Fthreads&v=i9YpWp0hXgg)
➡ Buy Me A Coffee [https://link.githubawesome.com/buymea...](https://www.youtube.com/redirect?event=video_description&redir_token=QUFFLUhqbU13dkRoZHZ6a09sYy1RdW5XbDhKczVTVm5mUXxBQ3Jtc0tsbHNnbTVoeWctMFJPQnJzbUZ5Wkk0WW5Yb3k0TGJCLU9iem03NEp4U1lYYm9UZTlodUxLN1I2Y1hnOHZhN1cwbDdubExOcHhsc2JvM3NjemlQRkNCWnBkOVBZVW81c0tpakFKRkhkdTVZZWZNY0NuOA&q=https%3A%2F%2Flink.githubawesome.com%2Fbuymeacoffee&v=i9YpWp0hXgg)…...more

...more
Show less

How this was made

Auto-dubbed

Audio tracks for some languages were automatically generated. [Learn more](https://support.google.com/youtube/answer/15569972?hl=en)

## Chapters         View all

[**Introduction**  **Introduction** \\
\\
0:00](https://www.youtube.com/watch?v=i9YpWp0hXgg)

[**Introduction**](https://www.youtube.com/watch?v=i9YpWp0hXgg)

0:00

[**termcraft**  **termcraft** \\
\\
0:16](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

[**termcraft**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=16s)

0:16

[**Switchboard**  **Switchboard** \\
\\
0:41](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

[**Switchboard**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=41s)

0:41

[**Fortransky**  **Fortransky** \\
\\
1:06](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

[**Fortransky**](https://www.youtube.com/watch?v=i9YpWp0hXgg&t=66s)

1:06

Transcript

Follow along using the transcript.

Show transcript

[**Github Awesome**\\
\\
52.8K subscribers](https://www.youtube.com/@GithubAwesome)

[Videos](https://www.youtube.com/channel/UC9Rrud-8CaHokDtK9FszvRg/videos)[About](https://www.youtube.com/channel/UC9Rrud-8CaHokDtK9FszvRg/about)[Tiktok](https://www.youtube.com/redirect?event=Watch_SD_EP&redir_token=QUFFLUhqbk5ROHN6TGQ1Y2xiUzl6dXE2Ym11UzV2X3VXZ3xBQ3Jtc0ttWEdsS2RLVkFMQnRsdHdHcmEtMTlNZDRTakNsUWF4OVYwSjFKWnhmSzk3Ylh1RFJqS1JGNi1oZkVuS2F1SXlPSnVnemNOX1ZtVGhMMlc5YmlOSmNET2VQWm1pcGg0U1c2a1dwN0N1ZUFNaEVMRkc3cw&q=https%3A%2F%2Fwww.tiktok.com%2F%40github.awesome)[Instagram](https://www.youtube.com/redirect?event=Watch_SD_EP&redir_token=QUFFLUhqbWZ6R1YwNHBYUGhQRmZQSmk1VzYzMHVUTTdMQXxBQ3Jtc0tubDJ6NGNsRmdQV2RabzdHZ1BBd2dDdm9sQXJ5Tl84cTFJOWpHQ3Z3dGxMRTNfRG9KYmxPUzQ0eFpOM3hkSU5PWmRQVkZBbEJJSEQ0dXRTb3B1dnZLTUJ2bnMyWmRYb3ctV3FZczYtZG94dkZJUW13dw&q=https%3A%2F%2Fwww.instagram.com%2Fgithub.awesome%2F)

## Transcript

NaN / NaN

[![](https://i.ytimg.com/vi/dtcgzGAeUZA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC0uXcHB8iL-z-Ins-Lrud6tTJl3A)\\
\\
22:48](https://www.youtube.com/watch?v=dtcgzGAeUZA)

### [Cursor's new model is NOT what it seems...](https://www.youtube.com/watch?v=dtcgzGAeUZA)

Wes Roth

15K views • 8 hours ago

New

[![](https://i.ytimg.com/vi/kwSVtQ7dziU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCBZVADa7hzE5H0FMp70mD4AUxJvQ)\\
\\
1:06:32](https://www.youtube.com/watch?v=kwSVtQ7dziU)

### [The End of Coding: Andrej Karpathy on Agents, AutoResearch, and the Loopy Era of AI](https://www.youtube.com/watch?v=kwSVtQ7dziU)

No Priors: AI, Machine Learning, Tech, & Startups

348K views • 2 days ago

New

[![](https://i.ytimg.com/vi/tEMvyiHwBFY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAFsIoEhKayPaIf15r-Qh1eBHgqjg)\\
\\
6:14](https://www.youtube.com/watch?v=tEMvyiHwBFY)

### [SNL Hosts Making the Cast BREAK for 6 Minutes Straight](https://www.youtube.com/watch?v=tEMvyiHwBFY)

PopMojo

6.5M views • 11 months ago

[![](https://i.ytimg.com/vi/XKsn3i9yYjU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBBXVKTQf1Njpo4LCBgaLvqZzNPaw)\\
\\
16:10](https://www.youtube.com/watch?v=XKsn3i9yYjU&pp=ugUHEgVlbi1VU9IHCQnFCgGHKiGM7w%3D%3D)

### [You Need to Stop Using Claude Like a Chatbot. Here’s Why.](https://www.youtube.com/watch?v=XKsn3i9yYjU&pp=ugUHEgVlbi1VU9IHCQnFCgGHKiGM7w%3D%3D)

Dylan Davis

25K views • 1 day ago

New

[![](https://i.ytimg.com/vi/8vokLcNNGCM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCroQBtMETS1lDR2y64arjGfOb7zw)\\
\\
11:15](https://www.youtube.com/watch?v=8vokLcNNGCM&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [AIR CANADA CRJ-900 Collision in NYC La Guardia Airport](https://www.youtube.com/watch?v=8vokLcNNGCM&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

Pilot Blog

118K views • 6 hours ago

New

[![](https://i.ytimg.com/vi/8Qc5U00IiAk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB1iRTHLQsPt7XoLnJEN7h8xxsqvA)\\
\\
26:51](https://www.youtube.com/watch?v=8Qc5U00IiAk)

### [How Bad is Private Credit?](https://www.youtube.com/watch?v=8Qc5U00IiAk)

Patrick Boyle

513K views • 2 days ago

New

[![](https://i.ytimg.com/vi/jH2ZIUKvazU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCJ3nJ9bvNj_TU_Shp3UCLHcjHbgg)\\
\\
1:01:14](https://www.youtube.com/watch?v=jH2ZIUKvazU)

### [Benedict Evans: OpenAI’s Moat Problem & the Future of Software](https://www.youtube.com/watch?v=jH2ZIUKvazU)

The MAD Podcast with Matt Turck

9.3K views • 4 days ago

New

[![](https://i.ytimg.com/vi/19AUlTi-Ki8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCTR1TEdDntT0u-Wt4mrTvVYM222w)\\
\\
15:37](https://www.youtube.com/watch?v=19AUlTi-Ki8&pp=ugUHEgVlbi1VUw%3D%3D)

### [GitHub Trending Today \#27: Ichinichi, Recordly, Notchi, gabagool, Antfly, Horizo​​n, Slug, Slim, Lux](https://www.youtube.com/watch?v=19AUlTi-Ki8&pp=ugUHEgVlbi1VUw%3D%3D)

Github Awesome

6K views • 2 days ago

New

[![](https://i.ytimg.com/vi/FUBVuvstPCs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBEm3Ux0lxXJondDVwP8Zb8KiufHA)\\
\\
3:39](https://www.youtube.com/watch?v=FUBVuvstPCs)

### [MAHAspital - SNL](https://www.youtube.com/watch?v=FUBVuvstPCs)

Saturday Night Live

3.2M views • 8 days ago

[![](https://i.ytimg.com/vi/QGnKTRtEH50/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD6RmwzlbxqeFcQtdpwhp6rTbuOeg)\\
\\
27:48](https://www.youtube.com/watch?v=QGnKTRtEH50&pp=0gcJCcUKAYcqIYzv)

### [Did Cursor really just rebrand Kimi???](https://www.youtube.com/watch?v=QGnKTRtEH50&pp=0gcJCcUKAYcqIYzv)

Theo - t3․gg

47K views • 19 hours ago

New

[![](https://i.ytimg.com/vi/6PJd08t_n0U/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC2PuGeE1sEaNRGcQk-345BPC011A)\\
\\
15:03](https://www.youtube.com/watch?v=6PJd08t_n0U&pp=ugUHEgVlbi1VUw%3D%3D)

### [Microsoft Just Proved AI Doesn’t Need GPUs](https://www.youtube.com/watch?v=6PJd08t_n0U&pp=ugUHEgVlbi1VUw%3D%3D)

Dr. Know-it-all Knows it all

48K views • 9 days ago

[![](https://i.ytimg.com/vi/zCLOAKSpq3U/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAuzBQILxfUSWTJO84UQyIkhatkOg)\\
\\
10:29](https://www.youtube.com/watch?v=zCLOAKSpq3U)

### [LaGuardia Airport closed after plane collision kills 2](https://www.youtube.com/watch?v=zCLOAKSpq3U)

CNN

129K views • 2 hours ago

New

[![](https://i.ytimg.com/vi/geIKyDaXwGg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBPXfaTJCFchrI-pgjhBkMUFuyfBg)\\
\\
55:32](https://www.youtube.com/watch?v=geIKyDaXwGg)

### [The next 45 min with Claude will change how you work forever.](https://www.youtube.com/watch?v=geIKyDaXwGg)

ICOR with Tom \| AI Productivity

26K views • 18 hours ago

New

[![](https://i.ytimg.com/vi/YTLnnoZPALI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB4W_s0PERg2NCUQBYlA1uwgCr1sg)\\
\\
9:50](https://www.youtube.com/watch?v=YTLnnoZPALI&pp=ugUHEgVlbi1VUw%3D%3D)

### [How AI Will Fail Like The Music Industry](https://www.youtube.com/watch?v=YTLnnoZPALI&pp=ugUHEgVlbi1VUw%3D%3D)

Rick Beato

1M views • 11 days ago

[![](https://i.ytimg.com/vi/ldxFjLJ3rVY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA5E99JWxxrv2W9ND9BSrUEOicjtw)\\
\\
44:52](https://www.youtube.com/watch?v=ldxFjLJ3rVY)

### [This picture broke my brain](https://www.youtube.com/watch?v=ldxFjLJ3rVY)

3Blue1Brown

374K views • 1 day ago

New

[![](https://i.ytimg.com/vi/e7a89ZYcTo8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAtBVeGlj5ym0JK0DI0xTiZIJLYUg)\\
\\
21:07](https://www.youtube.com/watch?v=e7a89ZYcTo8&pp=ugUEEgJlbg%3D%3D)

### [The Real Reason Windows Hate Is Exploding: It's Not Just the UI—It's the End of Personal Computing](https://www.youtube.com/watch?v=e7a89ZYcTo8&pp=ugUEEgJlbg%3D%3D)

Rob Braxman Tech

453K views • 11 days ago

[![](https://i.ytimg.com/vi/ZtnqqnKE4GM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBTiOMe2SCI-jHFaxK7cwDu23aQ6Q)\\
\\
6:49](https://www.youtube.com/watch?v=ZtnqqnKE4GM&pp=ugUHEgVlbi1VUw%3D%3D)

### [Dear XQC](https://www.youtube.com/watch?v=ZtnqqnKE4GM&pp=ugUHEgVlbi1VUw%3D%3D)

The PrimeTime

20K views • 1 hour ago

New

[![](https://i.ytimg.com/vi/v-6nm3gnh6g/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCmeVmGBuPU8_zQnT1iS8bn_WKSCg)\\
\\
15:10](https://www.youtube.com/watch?v=v-6nm3gnh6g&pp=ugUHEgVlbi1VUw%3D%3D)

### [Trending AI Projects \#3: NVIDIA NemoClaw, nightingale, OpenViktor, AutoResearchClaw, OpenHanako](https://www.youtube.com/watch?v=v-6nm3gnh6g&pp=ugUHEgVlbi1VUw%3D%3D)

Github Awesome

4.3K views • 3 days ago

New

[![](https://i.ytimg.com/vi/vqnAOV8NMZ4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCGwF8cQhibK3Vi8RH6HLTVBNMPAQ)\\
\\
33:30](https://www.youtube.com/watch?v=vqnAOV8NMZ4&pp=ugUEEgJlbg%3D%3D)

### [I Added One Anthropic Command. My AI Stopped Waiting for Me to Show Up. (Open Brain)](https://www.youtube.com/watch?v=vqnAOV8NMZ4&pp=ugUEEgJlbg%3D%3D)

AI News & Strategy Daily \| Nate B Jones

85K views • 2 days ago

New

[![](https://i.ytimg.com/vi/uOGHXAfvK8w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBbtRHpFB9csT5azhboVz41TC00Hg)\\
\\
2:17:03](https://www.youtube.com/watch?v=uOGHXAfvK8w)

### [Jensen's $1T Call, Anthropic Is Winning, Tesla's Fab Bet & Why CS Jobs Are Vanishing \| 240](https://www.youtube.com/watch?v=uOGHXAfvK8w)

Peter H. Diamandis

144K views • 1 day ago

New

[![](https://i.ytimg.com/vi/qRA0MyPlEPE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBg4ODN7mu6R4cloQJ_CowZKAEnBA)\\
\\
14:33](https://www.youtube.com/watch?v=qRA0MyPlEPE&pp=ugUEEgJlbg%3D%3D)

### [5 OpenClaw use cases you need to implement IMMEDIATELY (March 2026 edition)](https://www.youtube.com/watch?v=qRA0MyPlEPE&pp=ugUEEgJlbg%3D%3D)

Alex Finn

32K views • 23 hours ago

New

[![](https://i.ytimg.com/vi/pAQqkI0xMu4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBmxhI4Sw86a4zev9LNhOu_Zy-TGQ)\\
\\
17:08](https://www.youtube.com/watch?v=pAQqkI0xMu4)

### [Smart Engineers Are Moving Away From Github, Here's Why...](https://www.youtube.com/watch?v=pAQqkI0xMu4)

Mischa van den Burg

73K views • 2 weeks ago

[![](https://i.ytimg.com/vi/ll784fIsQew/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAKmdUAuNExyGLkN5A-mqYyl-HxxQ)\\
\\
25:36](https://www.youtube.com/watch?v=ll784fIsQew)

### [Why Boston Dynamics' New Atlas is Years Ahead of Tesla](https://www.youtube.com/watch?v=ll784fIsQew)

PRO ROBOTS

178K views • 2 weeks ago

[![](https://i.ytimg.com/vi/FzF-bV9Sigc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAUcudztkzOEgRw6trGHdfqvctRMg)\\
\\
18:14](https://www.youtube.com/watch?v=FzF-bV9Sigc)

### [NVIDIA Swears DLSS 5 Looks Better. Few Believe Them](https://www.youtube.com/watch?v=FzF-bV9Sigc)

Bellular News

218K views • 4 days ago

New

[![](https://i.ytimg.com/vi/5nL-Eq1lpDU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCEd2Hb6nijNJ4GVAHnKWLY-gs3dg)\\
\\
17:38](https://www.youtube.com/watch?v=5nL-Eq1lpDU&pp=ugUHEgVlbi1HQg%3D%3D)

### [I Fixed The YouTube Algorithm](https://www.youtube.com/watch?v=5nL-Eq1lpDU&pp=ugUHEgVlbi1HQg%3D%3D)

PewDiePie

2.5M views • 6 days ago

New

[![](https://i.ytimg.com/vi/KsiuA5gOl1o/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBff_X5L485SHcgbXEi5lYNbJO7Cw)\\
\\
15:45](https://www.youtube.com/watch?v=KsiuA5gOl1o)

### [I Hacked This Temu Router. What I Found Should Be Illegal.](https://www.youtube.com/watch?v=KsiuA5gOl1o)

Low Level

2.9M views • 2 weeks ago

[![](https://i.ytimg.com/vi/ud7NEaHKP-k/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCOMN0Iw4CbHQ9D9dg4kym7G-VfSA)\\
\\
16:47](https://www.youtube.com/watch?v=ud7NEaHKP-k)

### [Linux Age Verification: FOSS in the Brave New World](https://www.youtube.com/watch?v=ud7NEaHKP-k)

ExplainingComputers

71K views • 23 hours ago

New

[![](https://i.ytimg.com/vi/hX7yG1KVYhI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCyRzCmxUIBFMAcILP4mBZ9ycy7vw)\\
\\
44:16](https://www.youtube.com/watch?v=hX7yG1KVYhI&pp=ugUEEgJlbg%3D%3D)

### [Building a REAL feature with Claude Code: every step explained](https://www.youtube.com/watch?v=hX7yG1KVYhI&pp=ugUEEgJlbg%3D%3D)

Matt Pocock

46K views • 4 days ago

New

[![](https://i.ytimg.com/vi/A1WLxHPYwQw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBiNvgUYBfqUuunEhZdlUNazZV5tA)\\
\\
15:18](https://www.youtube.com/watch?v=A1WLxHPYwQw&pp=0gcJCcUKAYcqIYzv)

### [Ukraine is Planning Something MASSIVE](https://www.youtube.com/watch?v=A1WLxHPYwQw&pp=0gcJCcUKAYcqIYzv)

Paul Warburg

136K views • 8 hours ago

New

[![](https://i.ytimg.com/vi/h3KP3uXGsLI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC0l_CxizsrzcVAraHbHc6iGvRv8A)\\
\\
8:56](https://www.youtube.com/watch?v=h3KP3uXGsLI&pp=ugUHEgVlbi1VUw%3D%3D)

### [OpenClaw Explained: Why the Hype is (Mostly) Wrong](https://www.youtube.com/watch?v=h3KP3uXGsLI&pp=ugUHEgVlbi1VUw%3D%3D)

Udacity

143K views • 10 days ago

[![](https://i.ytimg.com/vi/V4un_4uTEHs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAPfBiNv5lZ06ksy6bAVE4MmP9BfA)\\
\\
35:30](https://www.youtube.com/watch?v=V4un_4uTEHs&pp=ugUEEgJlbg%3D%3D)

### [AI News: We've Entered The "Vibe Design" Era!](https://www.youtube.com/watch?v=V4un_4uTEHs&pp=ugUEEgJlbg%3D%3D)

Matt Wolfe

64K views • 2 days ago

New

[![](https://i.ytimg.com/vi/G7ru4h4Zi-w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDu94RuA4aby-AmkcBzGXs8I3uAAA)\\
\\
17:54](https://www.youtube.com/watch?v=G7ru4h4Zi-w)

### [I Just Can’t Stop Buying These Adapters](https://www.youtube.com/watch?v=G7ru4h4Zi-w)

Hardware Haven

88K views • 21 hours ago

New

[![](https://i.ytimg.com/vi/nkY_s9HpL9M/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBdnh_9xYAwWN4DSfYyWBElwDR8Og)\\
\\
4:49](https://www.youtube.com/watch?v=nkY_s9HpL9M)

### [This new Linux distro is breaking the law, by design…](https://www.youtube.com/watch?v=nkY_s9HpL9M)

Fireship

581K views • 2 days ago

New

[![](https://i.ytimg.com/vi/iJEZ59xJDR8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBQNchFPeZyhXbJ7LeSZ77keGM30A)\\
\\
10:07](https://www.youtube.com/watch?v=iJEZ59xJDR8)

### [The Real Problem With Idris Elba Playing James Bond](https://www.youtube.com/watch?v=iJEZ59xJDR8)

Trevor Noah

166K views • 1 day ago

New

[![](https://i.ytimg.com/vi/FRAZQKkhwrs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDG04QFfETbvQphRAN49aTcB61XjQ)\\
\\
21:29](https://www.youtube.com/watch?v=FRAZQKkhwrs&pp=ugUEEgJlbg%3D%3D)

### [If You Think The Bible Is FAKE, You NEED To See This](https://www.youtube.com/watch?v=FRAZQKkhwrs&pp=ugUEEgJlbg%3D%3D)

The Diary Of A CEO Clips

321K views • 1 day ago

New

[![](https://i.ytimg.com/vi/HCVkBC1Vhcw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCm7QSDW2Agqui9HvybRutP9X93RA)\\
\\
48:33](https://www.youtube.com/watch?v=HCVkBC1Vhcw&pp=ugUEEgJlbg%3D%3D)

### [AI classrooms, self-evolving AI, Nvidia GTC, AI for polymarket, Google app builder: AI NEWS](https://www.youtube.com/watch?v=HCVkBC1Vhcw&pp=ugUEEgJlbg%3D%3D)

AI Search

59K views • 1 day ago

New

[![](https://i.ytimg.com/vi/SCPU_H3QNqo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC10puhOXDpY9Xg7HsZYNVClKpTUQ)\\
\\
20:26](https://www.youtube.com/watch?v=SCPU_H3QNqo)

### [A-10 Warthogs Just Did Something HUGE to Open Straits of Hormuz](https://www.youtube.com/watch?v=SCPU_H3QNqo)

Max Afterburner

904K views • 2 days ago

New

[![](https://i.ytimg.com/vi/sGzMloTFPyU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCC2FgDIa76TYrw2RATC2ERkkB2NQ)\\
\\
2:35:03](https://www.youtube.com/watch?v=sGzMloTFPyU)

### [Antigravity 2 Hour Masterclass: Build & Sell AI Agents & Apps (No Code)](https://www.youtube.com/watch?v=sGzMloTFPyU)

Jono Catliff

32K views • 3 weeks ago

[![](https://i.ytimg.com/vi/ot3NM5OVFmc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDCEFSzLMGxRI4QLDCtGzxXpTstcQ)\\
\\
21:00](https://www.youtube.com/watch?v=ot3NM5OVFmc&pp=ugUEEgJlbg%3D%3D)

### [Claude Channels Just Dropped, And It Kills OpenClaw (Again)](https://www.youtube.com/watch?v=ot3NM5OVFmc&pp=ugUEEgJlbg%3D%3D)

Nick Saraev

45K views • 2 days ago

New

[![](https://i.ytimg.com/vi/HW6O3k6QqQc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDqiAn4ERdwzbU4j2f6k8AM0oq9sA)\\
\\
21:46](https://www.youtube.com/watch?v=HW6O3k6QqQc&pp=ugUEEgJlbg%3D%3D)

### [Elon Reveals TERAFAB (Tesla & SpaceX) - Full Replay - “Becoming a galactic civilization”](https://www.youtube.com/watch?v=HW6O3k6QqQc&pp=ugUEEgJlbg%3D%3D)

Solving The Money Problem

139K views • 1 day ago

New

[![](https://i.ytimg.com/vi/uULvhQrKB_c/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBcplUjQGM_d5YN_SDJ8gPsV9YWxg)\\
\\
14:04](https://www.youtube.com/watch?v=uULvhQrKB_c&pp=ugUEEgJlbg%3D%3D)

### [10 CLI Tools That Make Claude Code UNSTOPPABLE](https://www.youtube.com/watch?v=uULvhQrKB_c&pp=ugUEEgJlbg%3D%3D)

Chase AI

28K views • 1 day ago

New

[![](https://i.ytimg.com/vi/xQEPRWaFFLE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDCHQL17G79uIF54gRc2RlbznEP2w)\\
\\
8:15](https://www.youtube.com/watch?v=xQEPRWaFFLE)

### [Christian nationalists are TERRIFIED of James Talarico’s faith. This is why.](https://www.youtube.com/watch?v=xQEPRWaFFLE)

MS NOW

156K views • 11 hours ago

New

[![](https://i.ytimg.com/vi/H1a8YEOlpeY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCJL6uwGpfidVyCVbDHx4ZmB2d5Ow)\\
\\
31:29](https://www.youtube.com/watch?v=H1a8YEOlpeY)

### [NVIDIA Says You're "Completely Wrong" About DLSS 5 Being Slop](https://www.youtube.com/watch?v=H1a8YEOlpeY)

Gamers Nexus

710K views • 4 days ago

New

[![](https://i.ytimg.com/vi/E7C2msOl2gQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDnWbIzdMiWEK4h9_j9rCqF_F0l6g)\\
\\
15:16](https://www.youtube.com/watch?v=E7C2msOl2gQ&pp=ugUHEgVlbi1VUw%3D%3D)

### [GitHub Trending Weekly \#27: Remodex, chrome-cdp, GSD 2, TADA, ATLAS, skales, AutoResearchClaw](https://www.youtube.com/watch?v=E7C2msOl2gQ&pp=ugUHEgVlbi1VUw%3D%3D)

Github Awesome

6.6K views • 5 days ago

New

[![](https://i.ytimg.com/vi/ofLvTNZEHVk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDSnmA66qZ6jY-qAQRryHxXPn91vg)\\
\\
15:10](https://www.youtube.com/watch?v=ofLvTNZEHVk)

### [Inside Claude Code: The Architecture of AI Agents](https://www.youtube.com/watch?v=ofLvTNZEHVk)

PY

2.4K views • 3 weeks ago

[![](https://i.ytimg.com/vi/lILVObugHtQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB6w_Yv6QVYTlsJK03cWkuua4wnjw)\\
\\
4:57](https://www.youtube.com/watch?v=lILVObugHtQ&pp=0gcJCcUKAYcqIYzv)

### [The Last Supper \| SNL UK](https://www.youtube.com/watch?v=lILVObugHtQ&pp=0gcJCcUKAYcqIYzv)

Sky TV

817K views • 1 day ago

New

[![](https://i.ytimg.com/vi/C7gJ_UxVnSk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC5WWCCqWHqMszAFCk2blqKZwcfoQ)\\
\\
12:45](https://www.youtube.com/watch?v=C7gJ_UxVnSk)

### [1000x faster than your database - SpacetimeDB 2.0](https://www.youtube.com/watch?v=C7gJ_UxVnSk)

SpacetimeDB

118K views • 3 weeks ago

[![](https://i.ytimg.com/vi/-efjdj4oICs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDr_wMLZmHRx8bmCg1DLYvZ0KBJcw)\\
\\
16:44](https://www.youtube.com/watch?v=-efjdj4oICs&pp=ugUEEgJlbg%3D%3D)

### [I Watched Back to the Future in 0.25x Speed and Here's What I Found](https://www.youtube.com/watch?v=-efjdj4oICs&pp=ugUEEgJlbg%3D%3D)

The Canadian Lad

420K views • 3 weeks ago

[![](https://i.ytimg.com/vi/OjeuXdTij4g/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD02pRr-sq_l0f5aFaSDUDjwa9igQ)\\
\\
20:51](https://www.youtube.com/watch?v=OjeuXdTij4g&pp=ugUEEgJlbg%3D%3D)

### [Elon Musk Unveils Insane New Product](https://www.youtube.com/watch?v=OjeuXdTij4g&pp=ugUEEgJlbg%3D%3D)

Farzad

427K views • 1 day ago

New

[![](https://i.ytimg.com/vi/MkN-ss2Nl10/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD20rooDn_a3M3znh43HfIc2GfUKg)\\
\\
23:19](https://www.youtube.com/watch?v=MkN-ss2Nl10)

### [Stop Building AI Agents. Use This Folder System Instead.](https://www.youtube.com/watch?v=MkN-ss2Nl10)

Jake Van Clief

43K views • 12 days ago

[![](https://i.ytimg.com/vi/st534T7-mdE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAN5Lz10d8c1fKdVdRGo21b5KY3gA)\\
\\
56:42](https://www.youtube.com/watch?v=st534T7-mdE&pp=ugUEEgJlbg%3D%3D)

### [The Ultimate Beginner’s Guide to OpenClaw](https://www.youtube.com/watch?v=st534T7-mdE&pp=ugUEEgJlbg%3D%3D)

Metics Media

536K views • 13 days ago

[![](https://i.ytimg.com/vi/tZaMBGhbz9I/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBGhAgzKJBglu1RVPxXGBjqITV7-Q)\\
\\
11:36](https://www.youtube.com/watch?v=tZaMBGhbz9I&pp=ugUEEgJlbg%3D%3D)

### [Nvidia Trolls Gamers with DLSS 5](https://www.youtube.com/watch?v=tZaMBGhbz9I&pp=ugUEEgJlbg%3D%3D)

Paul's Hardware

65K views • 1 day ago

New

[![](https://i.ytimg.com/vi/Iywje6nF4pc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBw3GI8kmzqzT0Wqt7tb-793Z4xeQ)\\
\\
11:17](https://www.youtube.com/watch?v=Iywje6nF4pc&pp=ugUEEgJlbg%3D%3D)

### [BREAKING: Two pilots dead after plane collides with vehicle at LaGuardia Airport](https://www.youtube.com/watch?v=Iywje6nF4pc&pp=ugUEEgJlbg%3D%3D)

Fox News

210K views • 3 hours ago

New

[![](https://i.ytimg.com/vi/Fq7YnzT13sA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB2APgWiojklRk-KuNbxGS2E0Bncg)\\
\\
14:29](https://www.youtube.com/watch?v=Fq7YnzT13sA&pp=ugUHEgVlbi1VUw%3D%3D)

### [GitHub Trending Today \#26: TerraInk, engram, Overstory, Open Terminal, discrawl, kula, rustc-php](https://www.youtube.com/watch?v=Fq7YnzT13sA&pp=ugUHEgVlbi1VUw%3D%3D)

Github Awesome

9.3K views • 2 weeks ago

[![](https://i.ytimg.com/vi/TZUTe7s11-I/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCqyMEvYB2z7F2m5Gx0vXIFCKUF7g)\\
\\
22:48](https://www.youtube.com/watch?v=TZUTe7s11-I&pp=ugUHEgVlbi1HQg%3D%3D)

### [Claude Code + Nano Banana 2 = Insane $10,000 Websites](https://www.youtube.com/watch?v=TZUTe7s11-I&pp=ugUHEgVlbi1HQg%3D%3D)

Jack Roberts

311K views • 11 days ago

[![](https://i.ytimg.com/vi/fzAJWG8OzuU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBthV0xuTrEvUir3TYujH43wmwWJg)\\
\\
5:02](https://www.youtube.com/watch?v=fzAJWG8OzuU&pp=ugUEEgJlbg%3D%3D)

### [Wow. Trump is F\*\*\*ED](https://www.youtube.com/watch?v=fzAJWG8OzuU&pp=ugUEEgJlbg%3D%3D)

David Pakman Show

361K views • 13 hours ago

New

[![](https://i.ytimg.com/vi/UuBkRaEBtHM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBXuOb1ddejqsmb1RNW9_MNicqxYQ)\\
\\
1:43:08](https://www.youtube.com/watch?v=UuBkRaEBtHM&pp=0gcJCcUKAYcqIYzv)

### [James Webb Just Found Something That Breaks Our Universe](https://www.youtube.com/watch?v=UuBkRaEBtHM&pp=0gcJCcUKAYcqIYzv)

Late Science

15K views • 14 hours ago

New

[![](https://i.ytimg.com/vi/ozS3xQE9o6I/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAEhloXKtaQ4BVseRNn2VpCBA3gTw)\\
\\
15:26](https://www.youtube.com/watch?v=ozS3xQE9o6I)

### [“Humiliated!” Republicans’ huge plan BACKFIRES in devastating fashion](https://www.youtube.com/watch?v=ozS3xQE9o6I)

Brian Tyler Cohen

352K views • 8 hours ago

New

[![](https://i.ytimg.com/vi/4uzGDAoNOZc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCsZtwXI-zYjeNC1C3OD1WPzuwM_A)\\
\\
22:36](https://www.youtube.com/watch?v=4uzGDAoNOZc&pp=ugUHEgVlbi1VUw%3D%3D)

### [OpenClaw Creator: Why 80% Of Apps Will Disappear](https://www.youtube.com/watch?v=4uzGDAoNOZc&pp=ugUHEgVlbi1VUw%3D%3D)

Y Combinator

860K views • 1 month ago

[![](https://i.ytimg.com/vi/Fa5uDPBtb4w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDvpkEe7T4fpegc1lXXtSxUlPlhmA)\\
\\
15:36](https://www.youtube.com/watch?v=Fa5uDPBtb4w)

### [Strike On The Largest Oil Refinery💥Only A Few Hours Left Until Trump's Ultimatum Expires⏳ 2026.03.23](https://www.youtube.com/watch?v=Fa5uDPBtb4w)

Military Summary

26K views • 3 hours ago

New

[![](https://i.ytimg.com/vi/t87e44nZDLM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD0N-3Gdgy88CGeHPYFrHUVzEPerQ)\\
\\
8:12](https://www.youtube.com/watch?v=t87e44nZDLM)

### [Ground stop: Flights halted at LaGuardia after deadly collision](https://www.youtube.com/watch?v=t87e44nZDLM)

MS NOW

19K views • 2 hours ago

New

[![](https://i.ytimg.com/vi/sZQ7lqaOGMg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD0mAEswreVUcsYdVu841Y2VZQPGQ)\\
\\
21:26](https://www.youtube.com/watch?v=sZQ7lqaOGMg&pp=ugUHEgVlbi1HQg%3D%3D)

### [Google Stitch + Claude Code = Insane App Design](https://www.youtube.com/watch?v=sZQ7lqaOGMg&pp=ugUHEgVlbi1HQg%3D%3D)

Build Great Products

66K views • 3 days ago

New

[![](https://i.ytimg.com/vi/cSkoaCCmq0w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD8DBNYPjjQaS0eCDXgFl5vOil-Qg)\\
\\
22:02](https://www.youtube.com/watch?v=cSkoaCCmq0w&pp=ugUHEgVlbi1VUw%3D%3D)

### [Learn 90% Of Claude Code Agent Teams in 22 Minutes (Opus 4.6)](https://www.youtube.com/watch?v=cSkoaCCmq0w&pp=ugUHEgVlbi1VUw%3D%3D)

Bart Slodyczka

92K views • 1 month ago

[![](https://i.ytimg.com/vi/fj0tE2wwTVM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAiWj-PDWh0olIxoQToci0AOKZqwg)\\
\\
13:08](https://www.youtube.com/watch?v=fj0tE2wwTVM)

### [U.S. shipyards fall behind S. Korea & China](https://www.youtube.com/watch?v=fj0tE2wwTVM)

60 Minutes

111K views • 9 hours ago

New

[![](https://i.ytimg.com/vi/6Fyjf3gFjUk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAV_rYnV0om-HVBgibX6BvkJNXVGg)\\
\\
1:08:26](https://www.youtube.com/watch?v=6Fyjf3gFjUk)

### [SIGCSE TS 2026 - Saturday Keynote: "CS and SE Education, post-AI" by Titus Winters (Adobe)](https://www.youtube.com/watch?v=6Fyjf3gFjUk)

SIGCSE Technical Symposium

2.5K views • 2 weeks ago

[![](https://i.ytimg.com/vi/-u_igSQHAIo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBs0cGJWiUw4fK-tJievnVeD-9lKg)\\
\\
27:11](https://www.youtube.com/watch?v=-u_igSQHAIo)

### [Every Level of Claude Code Skills in 27 mins](https://www.youtube.com/watch?v=-u_igSQHAIo)

Simon Scrapes

23K views • 3 days ago

New

[![](https://i.ytimg.com/vi/spUNpyF58BY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDfgJo4jWiImAFo_r-NEkVNdc3bHQ)\\
\\
19:42](https://www.youtube.com/watch?v=spUNpyF58BY&pp=ugUHEgVlbi1VUw%3D%3D)

### [But what is the Fourier Transform? A visual introduction.](https://www.youtube.com/watch?v=spUNpyF58BY&pp=ugUHEgVlbi1VUw%3D%3D)

3Blue1Brown

11M views • 8 years ago

[![](https://i.ytimg.com/vi/Rl6_3ZWJbqA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDK0a9Yp2qadYTwxOLRlWASVy-uAg)\\
\\
20:37](https://www.youtube.com/watch?v=Rl6_3ZWJbqA&pp=ugUEEgJlbg%3D%3D)

### [eMMC Firmware Extraction - Hacking an AI Toy Robot](https://www.youtube.com/watch?v=Rl6_3ZWJbqA&pp=ugUEEgJlbg%3D%3D)

Matt Brown

703 views • 2 hours ago

New

[![](https://i.ytimg.com/vi/h5S2dBFLQHQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB822B-0NwJcXqeW-oHs9QgFthM_w)\\
\\
7:53](https://www.youtube.com/watch?v=h5S2dBFLQHQ&pp=ugUEEgJlbg%3D%3D)

### [OpenClaw Was Dangerous… Until NVIDIA Stepped In?](https://www.youtube.com/watch?v=h5S2dBFLQHQ&pp=ugUEEgJlbg%3D%3D)

ByteMonk

63K views • 2 days ago

New

[![](https://i.ytimg.com/vi/PGDkEKEfufw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD78Ww-lSIrTBRtB9O4xOjR1TOp8w)\\
\\
1:02:06](https://www.youtube.com/watch?v=PGDkEKEfufw)

### [1H Purpl Colors Mood Lights\| Radial gradient colors \| Screensaver \| LED Light \| Background](https://www.youtube.com/watch?v=PGDkEKEfufw)

Color Waves

2.5K views • 1 year ago

[![](https://i.ytimg.com/vi/1vTqBbBCH9w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDZBVXs82nrqOD1NJKrf4C9DX2q0w)\\
\\
10:42](https://www.youtube.com/watch?v=1vTqBbBCH9w)

### [Air Canada Express plane collides with ground vehicle at New York's LaGuardia Airport](https://www.youtube.com/watch?v=1vTqBbBCH9w)

CBS News

51K views • 6 hours ago

New

[![](https://i.ytimg.com/vi/9M_dq_0ljsc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBXjwbBrTMJunnpKQhYPSm_T99SkA)\\
\\
37:35](https://www.youtube.com/watch?v=9M_dq_0ljsc)

### [Clara Mattei: capitalism is not natural - it’s enforced](https://www.youtube.com/watch?v=9M_dq_0ljsc)

Channel 4 News

703K views • 1 month ago

[![](https://i.ytimg.com/vi/NtRPLCso0Sw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCnpXqdhyz25dovozzYFAqitBZhQQ)\\
\\
28:05](https://www.youtube.com/watch?v=NtRPLCso0Sw)

### [J.D. Vance: Last Week Tonight with John Oliver (HBO)](https://www.youtube.com/watch?v=NtRPLCso0Sw)

LastWeekTonight

3.9M views • 7 days ago

[![](https://i.ytimg.com/vi/SP23nGlqm8s/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA3dlIDdegXG9l32i1PN2PGCMuKxg)\\
\\
16:17](https://www.youtube.com/watch?v=SP23nGlqm8s&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [The iPad Changed Everything](https://www.youtube.com/watch?v=SP23nGlqm8s&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

ThisIsE

170K views • 1 day ago

New

[![](https://i.ytimg.com/vi/6AOF0qzei9k/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCCb8CkQibuIwvSJ7XfkQ3OdUvlSQ)\\
\\
20:09](https://www.youtube.com/watch?v=6AOF0qzei9k&pp=ugUEEgJlbg%3D%3D)

### [U.S. Unleashed Something CLASSIFIED on Iran… and Tehran Wasn’t Ready](https://www.youtube.com/watch?v=6AOF0qzei9k&pp=ugUEEgJlbg%3D%3D)

The Military Show

781K views • 19 hours ago

New

[![](https://i.ytimg.com/vi/V2gfNKxpVmg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBwUdeqFBHYf02QWDrXgUgGuU5xtA)\\
\\
11:02](https://www.youtube.com/watch?v=V2gfNKxpVmg&pp=ugUEEgJlbg%3D%3D)

### [How Iran flipped the economics of war against US \| Fareed's Take](https://www.youtube.com/watch?v=V2gfNKxpVmg&pp=ugUEEgJlbg%3D%3D)

CNN

962K views • 19 hours ago

New

[![](https://i.ytimg.com/vi/pvxNcQTcIy4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDseRN0zLCpqy2mMB9QsHwI3QUOTQ)\\
\\
9:57](https://www.youtube.com/watch?v=pvxNcQTcIy4)

### [Agent Skills or MCP in the era of Claude Code?](https://www.youtube.com/watch?v=pvxNcQTcIy4)

Confluent Developer

100K views • 13 days ago

[![](https://i.ytimg.com/vi/sccOohIswKU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLARDL-Dff3g_CelZOD3Zh-QOdsIDw)\\
\\
1:28:13](https://www.youtube.com/watch?v=sccOohIswKU)

### [Did Anything Change with AirPods Max 2?](https://www.youtube.com/watch?v=sccOohIswKU)

WVFRM Podcast

204K views • 2 days ago

New

[![](https://i.ytimg.com/vi/VS0ifZPzQ8Q/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBqgqlZZt32li3el0e2lz2Uh91AfA)\\
\\
26:37](https://www.youtube.com/watch?v=VS0ifZPzQ8Q&pp=ugUEEgJlbg%3D%3D)

### [Kennedy calls out Democrat who blocked his push to end senators' pay during shutdown: "I'll be back"](https://www.youtube.com/watch?v=VS0ifZPzQ8Q&pp=ugUEEgJlbg%3D%3D)

Senator John Kennedy

221K views • 16 hours ago

New

[![](https://i.ytimg.com/vi/nmGEedloQ6E/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBA9IWFNluAeUfOLwFxaSxCnCkIHg)\\
\\
34:04](https://www.youtube.com/watch?v=nmGEedloQ6E&pp=ugUEEgJlbg%3D%3D)

### [AI-Driven ESP32 Workflow (Spec → Code → Test) using Claude Code](https://www.youtube.com/watch?v=nmGEedloQ6E&pp=ugUEEgJlbg%3D%3D)

Andreas Spiess

31K views • 1 day ago

New

[![](https://i.ytimg.com/vi/jfKfPfyJRdk/hqdefault.jpg?v=6911ace0&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAPQlls0D-iIDsUxXGtm2b3tP1KLg)\\
\\
LIVE](https://www.youtube.com/watch?v=jfKfPfyJRdk)

### [lofi hip hop radio 📚 beats to relax/study to](https://www.youtube.com/watch?v=jfKfPfyJRdk)

Lofi Girl

24K watching

[![](https://i.ytimg.com/vi/CxErCGVo-oo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLClWah6WXzlQakXSa63CX7nUVoDNw)\\
\\
44:08](https://www.youtube.com/watch?v=CxErCGVo-oo&pp=ugUEEgJlbg%3D%3D)

### [The only OpenClaw tutorial you’ll ever need (March 2026 edition)](https://www.youtube.com/watch?v=CxErCGVo-oo&pp=ugUEEgJlbg%3D%3D)

Alex Finn

166K views • 5 days ago

New

[![](https://i.ytimg.com/vi/tPlIHBcpGt8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAIdCxDYmrh668pklCuMI8rYREiig)\\
\\
10:15](https://www.youtube.com/watch?v=tPlIHBcpGt8&pp=ugUHEgVlbi1VUw%3D%3D)

### [Can it get any worse?](https://www.youtube.com/watch?v=tPlIHBcpGt8&pp=ugUHEgVlbi1VUw%3D%3D)

The PrimeTime

297K views • 3 days ago

New

[![](https://i.ytimg.com/vi/0pvJmxe7LdE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCP71MaM1rWSK1NEQRGB0qe3OyHpg)\\
\\
29:16](https://www.youtube.com/watch?v=0pvJmxe7LdE)

### [Afroman's Winning High - Prosecutor Reacts](https://www.youtube.com/watch?v=0pvJmxe7LdE)

LegalEagle

1.4M views • 1 day ago

New

[![](https://i.ytimg.com/vi/F38BVVo2mHc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBPOY7lJ0hnQxaaKHF__G43YJo_jg)\\
\\
27:00](https://www.youtube.com/watch?v=F38BVVo2mHc)

### [Master 85% of Google AntiGravity in 27 Minutes (Beginners to Experts)](https://www.youtube.com/watch?v=F38BVVo2mHc)

Pro AI Income and Komal Bhojani

4.1K views • 12 days ago

[![](https://i.ytimg.com/vi/dbMXi9q78Tk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAx-PK9o6p2URxqjLL01gGvJDWIIw)\\
\\
23:08](https://www.youtube.com/watch?v=dbMXi9q78Tk)

### [I almost quit YouTube....](https://www.youtube.com/watch?v=dbMXi9q78Tk)

NetworkChuck

724K views • 11 days ago

[![](https://i.ytimg.com/vi/kluoZ9RhmVo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBWXuNvvkAtbLkxHPFxCDNHqOFweQ)\\
\\
28:20](https://www.youtube.com/watch?v=kluoZ9RhmVo)

### [FINE! I’ll Try Linux ONE MORE TIME….](https://www.youtube.com/watch?v=kluoZ9RhmVo)

Linus Tech Tips

2.1M views • 2 weeks ago

[![](https://i.ytimg.com/vi/PVs2VTPZ3dw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB3E-qnn9W7kXi_IECASHJqEF_ZdQ)\\
\\
43:02](https://www.youtube.com/watch?v=PVs2VTPZ3dw&pp=ugUEEgJlbg%3D%3D)

### [This AI Agent self-evolves (Hermes Explained)](https://www.youtube.com/watch?v=PVs2VTPZ3dw&pp=ugUEEgJlbg%3D%3D)

Igor Kudryk (Salesforce)

14K views • 2 days ago

New

[![](https://i.ytimg.com/vi/DnvWAP99r3Y/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC3hoDImzOdvJ6KH6f-0AGsLmZUOQ)\\
\\
2:29:07](https://www.youtube.com/watch?v=DnvWAP99r3Y)

### [Aging Expert: Can Aging Be Reversed? After 8 Weeks, Cells Appeared 75% Younger In Tests!](https://www.youtube.com/watch?v=DnvWAP99r3Y)

The Diary Of A CEO

and David Sinclair

125K views • 5 hours ago

New

[![](https://i.ytimg.com/vi/gwW8GKwHB3I/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDBrHJfgWf0gEqcpNc_T0jKUKjPdQ)\\
\\
1:06:06](https://www.youtube.com/watch?v=gwW8GKwHB3I)

### [Jensen Huang: Nvidia's Future, Physical AI, Rise of the Agent, Inference Explosion, AI PR Crisis](https://www.youtube.com/watch?v=gwW8GKwHB3I)

All-In Podcast

396K views • 3 days ago

New

[![](https://i.ytimg.com/vi/Z-ZkmpQBIFo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBXVzAXTAg7ZhQuEiwoCuzv3vsVNg)\\
\\
25:05](https://www.youtube.com/watch?v=Z-ZkmpQBIFo)

### [Algebra - How To Solve Equations Quickly!](https://www.youtube.com/watch?v=Z-ZkmpQBIFo)

The Organic Chemistry Tutor

4.8M views • 8 years ago

[![](https://i.ytimg.com/vi/l0Vqm0ZIySc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCQbxYVk63tXcQ1g9VSqJfQmRvgEw)\\
\\
30:54](https://www.youtube.com/watch?v=l0Vqm0ZIySc&pp=ugUEEgJlbg%3D%3D)

### [He Asked AI To Make Money. It Did.](https://www.youtube.com/watch?v=l0Vqm0ZIySc&pp=ugUEEgJlbg%3D%3D)

Chris Koerner on The Koerner Office Podcast

and The Koerner Office Highlights

219K views • 2 days ago

New

[![](https://i.ytimg.com/vi/LOhfqjmasi0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAGCByIYe7F7rE6QkYI9zFOSN1THA)\\
\\
1:17:12](https://www.youtube.com/watch?v=LOhfqjmasi0)

### [How to make a Video Game - Godot Beginner Tutorial](https://www.youtube.com/watch?v=LOhfqjmasi0)

Brackeys

7.1M views • 1 year ago

[![](https://i.ytimg.com/vi/sa3ELdTVEVs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBA5rJvNSgHDH3bSIRtNCmVS9JL_A)\\
\\
53:27](https://www.youtube.com/watch?v=sa3ELdTVEVs)

### [Manzil Dua \| Ruqyah Shariah \| 409 \| منزل daily recitation of manzil dua Cure and Protection by Evil](https://www.youtube.com/watch?v=sa3ELdTVEVs)

Quran Karim \| Syed Siraj ur Rehman

27K views • Streamed 3 weeks ago

[![](https://i.ytimg.com/vi/OFyECKgWXo8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDFkCUFmDWYApY1upxmAQdyDLdCKw)\\
\\
17:48](https://www.youtube.com/watch?v=OFyECKgWXo8)

### [10 Claude Code Plugins to 10X Your Projects](https://www.youtube.com/watch?v=OFyECKgWXo8)

Chase AI

59K views • 13 days ago

[![](https://i.ytimg.com/vi/7tGNaKA4xRs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDmiB8RT3J4spHO6S8mzis83t_Bew)\\
\\
1:00:01](https://www.youtube.com/watch?v=7tGNaKA4xRs)

### [LAVENDER PURPLE SCREEN 1 HOUR](https://www.youtube.com/watch?v=7tGNaKA4xRs)

Laughing Spoons - Color Screens & Screensavers

51K views • 4 years ago

[![](https://i.ytimg.com/vi/F2FmTdLtb_4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDESxyV9ccsHJmvx3uod7Ix_eHF1Q)\\
\\
53:38](https://www.youtube.com/watch?v=F2FmTdLtb_4)

### [System Design Concepts Course and Interview Prep](https://www.youtube.com/watch?v=F2FmTdLtb_4)

freeCodeCamp.org

2.4M views • 1 year ago

[![](https://i.ytimg.com/vi/c1PluBjD1v0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCYZZLsNRxOrJn3BxKGj0Z8qDTPUg)\\
\\
27:06](https://www.youtube.com/watch?v=c1PluBjD1v0)

### [Manjaro trouble, Germany mandates open formats, Google destroys sideloading - Linux Weekly News](https://www.youtube.com/watch?v=c1PluBjD1v0)

The Linux Experiment

42K views • 2 days ago

New

[![](https://i.ytimg.com/vi/EH5jx5qPabU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC1pPQGcJHkcxg7wyxKQO8mggi3mQ)\\
\\
25:58](https://www.youtube.com/watch?v=EH5jx5qPabU&pp=ugUEEgJlbg%3D%3D)

### [From Zero to Your First AI Agent in 25 Minutes (No Coding)](https://www.youtube.com/watch?v=EH5jx5qPabU&pp=ugUEEgJlbg%3D%3D)

Futurepedia

and AI Agent Lab

3.3M views • 10 months ago

[![](https://i.ytimg.com/vi/KdEKwLRSJYQ/hqdefault.jpg?v=68d36558&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB6E_X-EtdsFbHhTX6wlBHHx09EYQ)\\
\\
LIVE](https://www.youtube.com/watch?v=KdEKwLRSJYQ)

### [Relaxing Music to Relieve Stress, Anxiety and Depression • Mind, Body 🐬 Soothing music for nerves](https://www.youtube.com/watch?v=KdEKwLRSJYQ)

Heal Yourself

332 watching

[![](https://i.ytimg.com/vi/julbw1JuAz0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCqAgTUokopJQfK1bKsIk9y2Fg7wA)\\
\\
1:37:59](https://www.youtube.com/watch?v=julbw1JuAz0)

### [Building Claude Code with Boris Cherny](https://www.youtube.com/watch?v=julbw1JuAz0)

The Pragmatic Engineer

242K views • 2 weeks ago

[![](https://i.ytimg.com/vi/rRrBbyv3ChM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBttHzA0xujHYT54IAIKM4fMblxCQ)\\
\\
49:17](https://www.youtube.com/watch?v=rRrBbyv3ChM&pp=ugUEEgJlbg%3D%3D)

### [FULL Claude Tutorial for Beginners in 2026! (Become a PRO!)](https://www.youtube.com/watch?v=rRrBbyv3ChM&pp=ugUEEgJlbg%3D%3D)

AI Foundations

192K views • 13 days ago

[![](https://i.ytimg.com/vi/MPTNHrq_4LU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD9MiafDo1YF9PP7tN3F2vsHHViLA)\\
\\
27:44](https://www.youtube.com/watch?v=MPTNHrq_4LU)

### [Full interview: Anthropic CEO responds to Trump order, Pentagon clash](https://www.youtube.com/watch?v=MPTNHrq_4LU)

CBS News

and 2 more

1.8M views • 3 weeks ago

[![](https://i.ytimg.com/vi/RfljpemhYes/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAITM_eQ3AXAzGpbBtUe0mqFYon7g)\\
\\
1:04:15](https://www.youtube.com/watch?v=RfljpemhYes&list=RDRfljpemhYes&start_radio=1&pp=oAcB)

### [QUIET TIME WITH JESUS - Soaking worship instrumental \| Prayer and Devotional](https://www.youtube.com/watch?v=RfljpemhYes&list=RDRfljpemhYes&start_radio=1&pp=oAcB)

Central Record

1.3M views • 10 months ago

[![](https://i.ytimg.com/vi/X0czjWVqMdE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAVRMtJLcClXye3A0JaDIEsJmIfAg)\\
\\
24:28](https://www.youtube.com/watch?v=X0czjWVqMdE)

### [Finding Jobs with OpenClaw: Part 1 (Day 1 of OpenClaw for 100 Days)](https://www.youtube.com/watch?v=X0czjWVqMdE)

OpenClaw Dev

3.2K views • 1 month ago

[![](https://i.ytimg.com/vi/7tO7o92dHOM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDyMFYt0cn-WAYZPwnWLtC0_FvAeA)\\
\\
19:33](https://www.youtube.com/watch?v=7tO7o92dHOM)

### [Sole US Navy Oiler in the Middle East - USNS Big Horn - Damaged \| September 23, 2024](https://www.youtube.com/watch?v=7tO7o92dHOM)

What's Going on With Shipping?

605K views • 1 year ago

[![](https://i.ytimg.com/vi/Pw0-GoRyLUc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDaUjPfM7rlPwWXDUaNejfGI8RFZA)\\
\\
1:12:47](https://www.youtube.com/watch?v=Pw0-GoRyLUc&pp=0gcJCcUKAYcqIYzv)

### [👉✝️ Jonah and the Whale / Daniel and the Lions' Den / Nativity - Beginners Bible](https://www.youtube.com/watch?v=Pw0-GoRyLUc&pp=0gcJCcUKAYcqIYzv)

The Beginners Bible

155K views • 5 years ago

[![](https://i.ytimg.com/vi/7j_NE6Pjv-E/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDQdeNGDpzdJiMWzE-9RdAJEuxLuQ)\\
\\
20:18](https://www.youtube.com/watch?v=7j_NE6Pjv-E&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [Model Context Protocol (MCP), clearly explained (why it matters)](https://www.youtube.com/watch?v=7j_NE6Pjv-E&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

Greg Isenberg

1.2M views • 1 year ago

[![](https://i.ytimg.com/vi/rVEoyx349Hk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDuRI8MXjV15kTmcKPsJxP-w_V_fw)\\
\\
20:48](https://www.youtube.com/watch?v=rVEoyx349Hk&pp=ugUEEgJlbg%3D%3D)

### [567 Hours of Claude Code Lessons in 20 Minutes](https://www.youtube.com/watch?v=rVEoyx349Hk&pp=ugUEEgJlbg%3D%3D)

Chase AI

52K views • 3 weeks ago

[![](https://i.ytimg.com/vi/Il-ZpBuC8tA/hqdefault.jpg?v=69905cf3&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDLxRx9vtgafhWX0sIF9iKRXtGK-Q)\\
\\
LIVE](https://www.youtube.com/watch?v=Il-ZpBuC8tA)

### [Best of Deep House \[2026\] \| Melodic House & Progressive Flow](https://www.youtube.com/watch?v=Il-ZpBuC8tA)

DDD.

1.3K watching

[![](https://i.ytimg.com/vi/tyqwN-8aTNs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBwre6N3WV5i8pXLBQyjeAp-bSXDw)\\
\\
39:22](https://www.youtube.com/watch?v=tyqwN-8aTNs)

### [🔴 LIVE: Abdul Habib Attari \| Sunnaton Bhara Bayan \| Bayan](https://www.youtube.com/watch?v=tyqwN-8aTNs)

Abdul Habib Attari

39K views • Streamed 1 year ago

[![](https://i.ytimg.com/vi/hE5kUq--KqI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDkWt1CyrPIMv2xkWuHsckf83F-2w)\\
\\
28:13](https://www.youtube.com/watch?v=hE5kUq--KqI)

### [Decimals to Fractions](https://www.youtube.com/watch?v=hE5kUq--KqI)

The Organic Chemistry Tutor

856K views • 7 years ago

[![](https://i.ytimg.com/vi/I3tB78ggLrw/hqdefault.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAHwAQH4Af4JgALQBYoCDAgAEAEYfyATKHowDw==&rs=AOn4CLDf9MlXvwctlazmOWL9KB-L8_hLPA)\\
\\
1:01:44](https://www.youtube.com/watch?v=I3tB78ggLrw)

### [1H Pink Colors Mood Lights Part2 \| Radial gradient colors \| Screensaver \| LED Light \| Background](https://www.youtube.com/watch?v=I3tB78ggLrw)

Color Waves

3.5K views • 11 months ago

[![](https://i.ytimg.com/vi/0Tch0N5nsRU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCZyuy1Q0SL8W6yVWXdIWTJ1B72RQ)\\
\\
17:49](https://www.youtube.com/watch?v=0Tch0N5nsRU)

### [You’re not behind (yet): How to learn AI in 18 minutes](https://www.youtube.com/watch?v=0Tch0N5nsRU)

Dan Martell

675K views • 2 weeks ago

[![](https://i.ytimg.com/vi/sesacY7Xz3c/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD1XlAdea4pMVZHeyAastXNvrtOQw)\\
\\
27:31](https://www.youtube.com/watch?v=sesacY7Xz3c)

### [Cybersecurity Architecture: Networks](https://www.youtube.com/watch?v=sesacY7Xz3c)

IBM Technology

477K views • 2 years ago

[![](https://i.ytimg.com/vi/OqiPOowunvQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAmkca4AQHt8wf9wR7MiC-o8Ld3iQ)\\
\\
1:15:05](https://www.youtube.com/watch?v=OqiPOowunvQ&list=RDOqiPOowunvQ&start_radio=1&pp=oAcB)

### [A MOMENT WITH JESUS - Instrumental worship Music + Prayer soaking Music With Holy Spirit](https://www.youtube.com/watch?v=OqiPOowunvQ&list=RDOqiPOowunvQ&start_radio=1&pp=oAcB)

1MOMENT

229K views • 1 year ago

[![](https://i.ytimg.com/vi/nTn9gVqRfKY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDTuEDajKa8kzs-DyEK3kjmIjuIaQ)\\
\\
21:42](https://www.youtube.com/watch?v=nTn9gVqRfKY)

### [Mental Math Tricks - Addition, Subtraction, Multiplication & Division!](https://www.youtube.com/watch?v=nTn9gVqRfKY)

The Organic Chemistry Tutor

1.9M views • 8 years ago

[![](https://i.ytimg.com/vi/GxmfcnU3feo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDd8JouH36rPCbxZnaVdOh5jSaaMQ)\\
\\
15:15](https://www.youtube.com/watch?v=GxmfcnU3feo&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [The Complete Web Development Roadmap](https://www.youtube.com/watch?v=GxmfcnU3feo&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

Programming with Mosh

1.2M views • 1 year ago

[![](https://i.ytimg.com/vi/gv0WHhKelSE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBWPb3v2uN0ony7x24l8T2p6mYDYQ)\\
\\
25:53](https://www.youtube.com/watch?v=gv0WHhKelSE&pp=ugUEEgJlbg%3D%3D)

### [Claude Code best practices \| Code w/ Claude](https://www.youtube.com/watch?v=gv0WHhKelSE&pp=ugUEEgJlbg%3D%3D)

Anthropic

410K views • 7 months ago

[![](https://i.ytimg.com/vi/wD6-p2mqc1o/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDQX_fP0Ahf8SETah5qOjhRhjd6Hw)\\
\\
34:18](https://www.youtube.com/watch?v=wD6-p2mqc1o&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [Ross Coulthart Q&A: Gen. McCasland, Robert Bigelow’s silence and what is alien.gov? \| Reality Check](https://www.youtube.com/watch?v=wD6-p2mqc1o&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

NewsNation

and Ross Coulthart

75K views • 1 day ago

New

[![](https://i.ytimg.com/vi/3_9vCamtuPY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAHzcsS7zBgkG0vxgK9KbEWbWLr0Q)\\
\\
2:30](https://www.youtube.com/watch?v=3_9vCamtuPY)

### [Dune: Part Three \| Official Teaser Trailer](https://www.youtube.com/watch?v=3_9vCamtuPY)

Warner Bros.

and 2 more

30M views • 5 days ago

New

[![](https://i.ytimg.com/vi/zxMjOqM7DFs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBOiBSWf5vjGtAnjyXWvijGlLn6DA)\\
\\
31:28](https://www.youtube.com/watch?v=zxMjOqM7DFs&pp=ugUHEgVlbi1VUw%3D%3D)

### [Claude Code Clearly Explained (and how to use it)](https://www.youtube.com/watch?v=zxMjOqM7DFs&pp=ugUHEgVlbi1VUw%3D%3D)

Greg Isenberg

322K views • 2 months ago

[![](https://i.ytimg.com/vi/C_DCKW2DzWM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBiajQuGG-_nGqD3VJMAtN4UNnWNw)\\
\\
26:33](https://www.youtube.com/watch?v=C_DCKW2DzWM)

### [What the Ship (Ep 123): Flag-Hopping \| EU & Insurance \| China Tariff \| COSCO \| IMO Carbon Tariff](https://www.youtube.com/watch?v=C_DCKW2DzWM)

What's Going on With Shipping?

292K views • 10 months ago

[![](https://i.ytimg.com/vi/pDELW2pIvWw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCwyIAzHt40xTU7lg7zreWmu-KrvA)\\
\\
56:25](https://www.youtube.com/watch?v=pDELW2pIvWw)

### [Digital Electronics - The First Video YOU Should Watch](https://www.youtube.com/watch?v=pDELW2pIvWw)

CaptiveAire

967K views • 2 years ago

[![](https://i.ytimg.com/vi/SHcTKVAdgV0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAT-pX--0OOfOdCn-JT8GLTE_FWrw)\\
\\
22:18](https://www.youtube.com/watch?v=SHcTKVAdgV0&pp=0gcJCcUKAYcqIYzv)

### [Full OpenClaw Setup on a VPS with TailScale VPN and Maximum Firewall](https://www.youtube.com/watch?v=SHcTKVAdgV0&pp=0gcJCcUKAYcqIYzv)

Rich Kuo

2.4K views • 2 weeks ago

[![](https://i.ytimg.com/vi/O8q9nnyK6Xw/hqdefault.jpg?v=690dc7f8&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBDWN9bSaaGVq8jSFictIZvUNPRxg)\\
\\
LIVE](https://www.youtube.com/watch?v=O8q9nnyK6Xw)

### [Warm Piano Jazz by the Fireplace \| Gentle Jazz with Peaceful Lakeview for Work, Study, Focus](https://www.youtube.com/watch?v=O8q9nnyK6Xw)

Tranquil Cafe Jazz

1.2K watching

[![](https://i.ytimg.com/vi/ZgfybHGxzJU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD77V_ETWogwE98Lr_XzFvAAN_eeA)\\
\\
15:33](https://www.youtube.com/watch?v=ZgfybHGxzJU&pp=ugUEEgJlbg%3D%3D)

### [Claude Code vs GSD 2: The Results Shocked Me](https://www.youtube.com/watch?v=ZgfybHGxzJU&pp=ugUEEgJlbg%3D%3D)

Chase AI

36K views • 5 days ago

New

[![](https://i.ytimg.com/vi/q7mPAufXv6U/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC3RSQq7Tvk7JxtfN-9PNVx_oPYZg)\\
\\
18:03](https://www.youtube.com/watch?v=q7mPAufXv6U)

### [Iran ATTACKS The Wrong U.S. Navy Ship – Big Mistake](https://www.youtube.com/watch?v=q7mPAufXv6U)

Beyond Military

1.8M views • 6 days ago

New

[![](https://i.ytimg.com/vi/GVGWFbVqA6A/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDy0yDuNsZcds4M3ncs1sN8kwfHaA)\\
\\
45:24](https://www.youtube.com/watch?v=GVGWFbVqA6A)

### [Low Stance in Tennis. Lesson for KIDS with PRO TENNIS COACH Vasileios Psyrras. Full Practice. Day 2](https://www.youtube.com/watch?v=GVGWFbVqA6A)

Alex The Tennis Pro

13K views • 3 years ago

[![](https://i.ytimg.com/vi/pJYOG6klqj8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDhEQcKfaUWE5ngxcjDJUV0ACiPDQ)\\
\\
46:14](https://www.youtube.com/watch?v=pJYOG6klqj8&pp=ugUEEgJlbg%3D%3D)

### [The Only GitHub Guide You’ll Ever Need](https://www.youtube.com/watch?v=pJYOG6klqj8&pp=ugUEEgJlbg%3D%3D)

corbin

151K views • 5 months ago

[![](https://i.ytimg.com/vi/MrBHNE7L_ME/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBatNI5ETvpfZrvjXdjI2UjAaBs7w)\\
\\
1:28:21](https://www.youtube.com/watch?v=MrBHNE7L_ME)

### [James Talarico's crazy Gospel of Thomas teaching: 10 Qs with Mike Winger (Ep 72)](https://www.youtube.com/watch?v=MrBHNE7L_ME)

Mike Winger

96K views • Streamed 2 days ago

New

[![](https://i.ytimg.com/vi/cZitIRcj-0M/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDm_czdsTPGZvwMOUl5lLO6FQ-swg)\\
\\
33:48](https://www.youtube.com/watch?v=cZitIRcj-0M&pp=ugUHEgVlbi1VUw%3D%3D)

### [An Analysis of Modern Republicanism \| Explainer](https://www.youtube.com/watch?v=cZitIRcj-0M&pp=ugUHEgVlbi1VUw%3D%3D)

Heather Cox Richardson

285K views • 1 day ago

New

[![](https://i.ytimg.com/vi/BHxcgGLUBCA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA12U36AQ6OMeW2ouNP_MTVOdD2aA)\\
\\
30:04](https://www.youtube.com/watch?v=BHxcgGLUBCA)

### [Warm Charcoal Gradient 4K Background Loop for Filming & Photos (NO SOUND)](https://www.youtube.com/watch?v=BHxcgGLUBCA)

Moodcraft Studio

8.1K views • 2 months ago

[![](https://i.ytimg.com/vi/SCMU176TYNc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAaIU1uwyMJytocKSzc-ddcHIzX7A)\\
\\
15:18](https://www.youtube.com/watch?v=SCMU176TYNc&pp=ugUHEgVlbi1VUw%3D%3D)

### [Tim Conway's Hilarious First Appearance](https://www.youtube.com/watch?v=SCMU176TYNc&pp=ugUHEgVlbi1VUw%3D%3D)

Johnny Carson

10M views • 2 years ago

[![](https://i.ytimg.com/vi/4qIRAtw4Ktg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDXf_Y_w4P5Wy5QqmeOYcYXOLV8dg)\\
\\
21:31](https://www.youtube.com/watch?v=4qIRAtw4Ktg)

### [Codex vs Claude Code: I Tested OpenAI's New Codex App](https://www.youtube.com/watch?v=4qIRAtw4Ktg)

The Next Wave - AI and the Future of Technology

23K views • 3 weeks ago

[![](https://i.ytimg.com/vi/nhbYveaV0pk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBJatnkD6I8yZ6u3jfqCk4e6nYI8Q)\\
\\
56:53](https://www.youtube.com/watch?v=nhbYveaV0pk)

### [Do It With Style: Rethinking CSS - Dylan Beattie - NDC London 2026](https://www.youtube.com/watch?v=nhbYveaV0pk)

NDC Conferences

58K views • 1 month ago

[![](https://i.ytimg.com/vi/q64cOs7GN_4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD54bHA65Bnz_Pvc2heDmGwc8rM2A)\\
\\
26:50](https://www.youtube.com/watch?v=q64cOs7GN_4&pp=0gcJCcUKAYcqIYzv)

### [Strait of Hormuz 3-Week Recap \| What is the Status of the Ships, Transits and Escort Mission?](https://www.youtube.com/watch?v=q64cOs7GN_4&pp=0gcJCcUKAYcqIYzv)

What's Going on With Shipping?

203K views • 1 day ago

New

[![](https://i.ytimg.com/vi/989oCEvMSSU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBzeyRPN1Ug0pGNQsZucSFq528DfA)\\
\\
28:19](https://www.youtube.com/watch?v=989oCEvMSSU)

### [Morning Adhkar (أذكار الصباح) Listen Every Morning for Barakah, Peace & Protection \|Peace Holy Quran](https://www.youtube.com/watch?v=989oCEvMSSU)

Peace - Holy Quran

59K views • 13 hours ago

New

[![](https://i.ytimg.com/vi/SrIPpxHeeq4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDhMjzzWnkmQ7gdm3tskTZiK3Ze7Q)\\
\\
1:00:30](https://www.youtube.com/watch?v=SrIPpxHeeq4)

### [Gold Framed TV Art Screensaver 4K. Vintage William Morris Floral Pattern Frame TV Hack - No Sound](https://www.youtube.com/watch?v=SrIPpxHeeq4)

Rhapsody Frame TV Art

19K views • 1 year ago

[![](https://i.ytimg.com/vi/VSdJ9s_6x6w/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAt1Kk4iKO3v0SKCBG7F6fbJreZtQ)\\
\\
1:11:07](https://www.youtube.com/watch?v=VSdJ9s_6x6w)

### [❗КАСПАРОВ. Россия на пороге смуты. СИСТЕМА ЛОМАЕТСЯ. Прямой эфир.](https://www.youtube.com/watch?v=VSdJ9s_6x6w)

Форум свободной России

115K views • Streamed 19 hours ago

New

[![](https://i.ytimg.com/vi/UxGbU_Xi13Q/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCwkK9qb3dNcDa60NSNucrQtVI3dw)\\
\\
8:32](https://www.youtube.com/watch?v=UxGbU_Xi13Q&pp=ugUHEgVlbi1VUw%3D%3D)

### [LAWYER: If Cops Say "I Smell Alcohol" - Say THIS](https://www.youtube.com/watch?v=UxGbU_Xi13Q&pp=ugUHEgVlbi1VUw%3D%3D)

Hampton Law

1.3M views • 7 days ago

[![](https://i.ytimg.com/vi/JwO3V8FdJrk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBSIY22WYkuOECLEHwElZkPb7oFIg)\\
\\
32:57](https://www.youtube.com/watch?v=JwO3V8FdJrk)

### [Ending THE DECADE With THE ENDER DRAGON!! \| Minecraft Hardcore](https://www.youtube.com/watch?v=JwO3V8FdJrk)

Thinknoodles

347K views • 6 years ago

[![](https://i.ytimg.com/vi/GuTcle5edjk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBTSKwGzTUWgcj0eyitfSD93OVLVg)\\
\\
38:40](https://www.youtube.com/watch?v=GuTcle5edjk&pp=ugUEEgJlbg%3D%3D)

### [you need to learn MCP RIGHT NOW!! (Model Context Protocol)](https://www.youtube.com/watch?v=GuTcle5edjk&pp=ugUEEgJlbg%3D%3D)

NetworkChuck

1.3M views • 6 months ago

[![](https://i.ytimg.com/vi/nA0M5MlohvM/hqdefault.jpg?v=69c01b87&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBeKHfMqeZflvOqet_oW7mnXLMcTg)\\
\\
LIVE](https://www.youtube.com/watch?v=nA0M5MlohvM)

### [Gurbani Kirtan Live \| 23-03-26 \| Gurbani Kirtan Today \| Gurbani Gur Sagar](https://www.youtube.com/watch?v=nA0M5MlohvM)

Gurbani Gur Sagar

544 watching

[![](https://i.ytimg.com/vi/ZdoX946L6a4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDVeiTVVXCztRQRSYCXTqbg2bejJA)\\
\\
1:13:21](https://www.youtube.com/watch?v=ZdoX946L6a4&pp=0gcJCcUKAYcqIYzv)

### [My Little Pony: Equestria Girls \| Rainbow Rocks \[Full HD\]](https://www.youtube.com/watch?v=ZdoX946L6a4&pp=0gcJCcUKAYcqIYzv)

Letupita725HD★

3.9M views • 7 months ago

[![](https://i.ytimg.com/vi/l8vxTYJbzSY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA5LhdHZPQfFSIkIX2ytSpM2k9RRg)\\
\\
13:45](https://www.youtube.com/watch?v=l8vxTYJbzSY)

### [How to Prepare MDF for Black and Metallic Paint](https://www.youtube.com/watch?v=l8vxTYJbzSY)

Adam Savage’s Tested

38K views • 23 hours ago

New

[![](https://i.ytimg.com/vi/bv5GerGTOEw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD9_tInaEfehezZOSErCnUfwSCEnQ)\\
\\
38:56](https://www.youtube.com/watch?v=bv5GerGTOEw&pp=ugUHEgVlbi1VUw%3D%3D)

### [Read The Korea Economic Daily in 30 Minutes \| 20260323🌞\#MorningRoutine \| 8 AM Live](https://www.youtube.com/watch?v=bv5GerGTOEw&pp=ugUHEgVlbi1VUw%3D%3D)

한경 코리아마켓

130K views • Streamed 13 hours ago

New

Auto-dubbed

[![](https://i.ytimg.com/vi/ke5KpqcoiIU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLABaCojfiIvc_TXn8G1nHWeUq1Jiw)\\
\\
49:43](https://www.youtube.com/watch?v=ke5KpqcoiIU)

### [How to make 3D Games in Godot](https://www.youtube.com/watch?v=ke5KpqcoiIU)

Brackeys

1.5M views • 1 year ago

[![](https://i.ytimg.com/vi/E2DEHOEbzks/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBVSukVi6igi3FPDkpA8vs0gUvEPw)\\
\\
24:10](https://www.youtube.com/watch?v=E2DEHOEbzks&pp=ugUHEgVlbi1HQtIHCQnFCgGHKiGM7w%3D%3D)

### [Model Context Protocol (MCP) Explained for Beginners: AI Flight Booking Demo!](https://www.youtube.com/watch?v=E2DEHOEbzks&pp=ugUHEgVlbi1HQtIHCQnFCgGHKiGM7w%3D%3D)

KodeKloud

847K views • 8 months ago

[![](https://i.ytimg.com/vi/HxZkfbwXPCI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAoaVwFIxMVucpL1PNIDK_aeaGaAw)\\
\\
1:10:09](https://www.youtube.com/watch?v=HxZkfbwXPCI)

### [Puzsér Róbert: A "mocskos Fidesz" ma már nemzeti minimum](https://www.youtube.com/watch?v=HxZkfbwXPCI)

444.hu

19K views • Streamed 3 hours ago

New

[![](https://i.ytimg.com/vi/1JrH41zAVEU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC3OMLRg3vzdvjXry5tA_PferTFDA)\\
\\
1:42:05](https://www.youtube.com/watch?v=1JrH41zAVEU)

### [Who Was Archbishop Marcel Lefebvre? - The Episcopal Consecrations - Episode 1](https://www.youtube.com/watch?v=1JrH41zAVEU)

SSPX News - English

11K views • 3 days ago

New

[![](https://i.ytimg.com/vi/yzvLfHb0nqE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDtU5cj5Uyt1gt6M_4gCTJUYOoyRg)\\
\\
20:16](https://www.youtube.com/watch?v=yzvLfHb0nqE)

### [Building AI Agents: Chat Trigger, Memory, and System/User Messages Explained \[Part 1\]](https://www.youtube.com/watch?v=yzvLfHb0nqE)

n8n

304K views • 1 year ago

[![](https://i.ytimg.com/vi/XdlE1sUvAYs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC0zdnWxhP8BgkPQjNXkMCC0RmbuA)\\
\\
21:07](https://www.youtube.com/watch?v=XdlE1sUvAYs)

### [Was ist der Urknall? 💥 l WOOZLE GOOZLE](https://www.youtube.com/watch?v=XdlE1sUvAYs)

Woozle Goozle

704K views • 4 years ago

[![](https://i.ytimg.com/vi/N5v2b42i_2g/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBZqabwdC9GZdUWWBxlz-HgfZ_BiA)\\
\\
19:17](https://www.youtube.com/watch?v=N5v2b42i_2g)

### [The Finance Paper That Changed Everything](https://www.youtube.com/watch?v=N5v2b42i_2g)

Ben Felix

89K views • 1 day ago

New

[![](https://i.ytimg.com/vi/IenefrTrnQc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLACZEkt-0RvfyNYPsECCICh6kwL9w)\\
\\
9:25](https://www.youtube.com/watch?v=IenefrTrnQc)

### [Could Greece Become Europe's Energy Hub?](https://www.youtube.com/watch?v=IenefrTrnQc)

TLDR News EU

27K views • 2 hours ago

New

[![](https://i.ytimg.com/vi/_x2Q44UTyrA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDp-b30Lfn5pDTTqbkbmyg6fj-pYg)\\
\\
16:55](https://www.youtube.com/watch?v=_x2Q44UTyrA&pp=ugUEEgJlbg%3D%3D)

### [Day 2 of Learn Autodesk Fusion in 30 Days! (2026 EDITION)](https://www.youtube.com/watch?v=_x2Q44UTyrA&pp=ugUEEgJlbg%3D%3D)

Product Design Online

9.4K views • 5 days ago

New

[![](https://i.ytimg.com/vi/20VJIlUn0Ys/hqdefault.jpg?v=699fe634&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC5wFr96FGkSYCLzG_a1c9yQSVtBw)\\
\\
LIVE](https://www.youtube.com/watch?v=20VJIlUn0Ys)

### [🔴 Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \|مكه المكرمه مباشر](https://www.youtube.com/watch?v=20VJIlUn0Ys)

Dua Quran Official

3K watching

[![](https://i.ytimg.com/vi/rcjyAjZTIN8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA_1SCrLCa1qTC1U_DIiSB91P8zeA)\\
\\
1:55:17](https://www.youtube.com/watch?v=rcjyAjZTIN8)

### [VeggieTales \| Musical Parables 🎸🎵 \| Lessons with Catchy Tunes](https://www.youtube.com/watch?v=rcjyAjZTIN8)

VeggieTales Official

144K views • 1 year ago

[![](https://i.ytimg.com/vi/TyMgKl90-D8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAQqCl7-7pDcMuLgMFLz-FhvzzWXA)\\
\\
21:03](https://www.youtube.com/watch?v=TyMgKl90-D8)

### [الحلقة الرابعة عشر ا أراحك الله ا عالمغرب (٣)](https://www.youtube.com/watch?v=TyMgKl90-D8)

إيه المشكلة

225K views • 2 weeks ago

[![](https://i.ytimg.com/vi/S_o3I0ro6Xk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDAfUFXUj0jqWKICPXkHwl2cHnFXQ)\\
\\
1:03:35](https://www.youtube.com/watch?v=S_o3I0ro6Xk)

### [أجمل قصص عن الرسول عليه أفضل الصلاة والسلام \- خطب بدر المشاري](https://www.youtube.com/watch?v=S_o3I0ro6Xk)

Ana Muslim life - أنا مسلم لايف

1.7M views • Streamed 2 years ago

[![](https://i.ytimg.com/vi/9ECRlejmJbU/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAHK7NmJ9W_8iFiaStlSUPwSV6kpQ)\\
\\
44:07](https://www.youtube.com/watch?v=9ECRlejmJbU)

### [سورة الرحمن كاملة \- عبد الباسط عبد الصمد \| Surah Ar-Rahman Abdulbasit Abdussamad](https://www.youtube.com/watch?v=9ECRlejmJbU)

روائع فضيلة الشيخ/ عبد الباسط عبد الصمد

655K views • Streamed 1 year ago

[![](https://i.ytimg.com/vi/-bxkjOyKa7E/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBZ54bOInyjsgIOpElyyy4PoePtsQ)\\
\\
22:00](https://www.youtube.com/watch?v=-bxkjOyKa7E)

### [Learn How Electric Guitars Are Made! 🎸😎 \| Made in a Day Full Episode \| @natgeokids](https://www.youtube.com/watch?v=-bxkjOyKa7E)

Nat Geo Kids

1M views • 1 month ago

[![](https://i.ytimg.com/vi/eg1__oCzDzI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBGy3ty64oax9YXlrhdzVeaR8mF5g)\\
\\
14:16](https://www.youtube.com/watch?v=eg1__oCzDzI&pp=ugUHEgVlbi1VUw%3D%3D)

### [Trending Open-Source Github Projects: MoneyPrinterV2, vllm-omni, Unsloth, OpenGauss & RCLI \#242](https://www.youtube.com/watch?v=eg1__oCzDzI&pp=ugUHEgVlbi1VUw%3D%3D)

ManuAGI - AutoGPT Tutorials

2.3K views • 21 hours ago

New

[![](https://i.ytimg.com/vi/L7c1eG8qOe4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAyAuY73M02NVfhCdebXPeOAWtuOA)\\
\\
22:53](https://www.youtube.com/watch?v=L7c1eG8qOe4)

### [Claude Code + OpenRouter: $0 Setup Guide](https://www.youtube.com/watch?v=L7c1eG8qOe4)

Thein Kyaw Lwin

2.7K views • 12 days ago

[![](https://i.ytimg.com/vi/bkIc4PhgSxs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCFcSUxrrZ8hi5P6K1lf2IPdE8XZw)\\
\\
23:22](https://www.youtube.com/watch?v=bkIc4PhgSxs)

### [How I scrape leads in SECONDS with Claude Code](https://www.youtube.com/watch?v=bkIc4PhgSxs)

David Mendoza

4.9K views • 1 month ago

[![](https://i.ytimg.com/vi/zAlCdjt4fd8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDnQp5-Za13xSNWvIq9e1BU87R6AQ)\\
\\
54:05](https://www.youtube.com/watch?v=zAlCdjt4fd8)

### [KINGDOM GEMS \| Ask. Seek. Knock. \| Matthew 7:7-12 \| Philip Anthony Mitchell](https://www.youtube.com/watch?v=zAlCdjt4fd8)

2819 Church

1.4M views • Streamed 2 years ago

[![](https://i.ytimg.com/vi/hVauhMT9RhA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCjHrX145DWvEDKW00sp5i__yRdsw)\\
\\
1:03:47](https://www.youtube.com/watch?v=hVauhMT9RhA&list=RDhVauhMT9RhA&start_radio=1&pp=oAcB)

### [ME & JESUS - Soaking worship instrumental \| Prayer and Devotional](https://www.youtube.com/watch?v=hVauhMT9RhA&list=RDhVauhMT9RhA&start_radio=1&pp=oAcB)

Central Record

488K views • 4 months ago

[![](https://i.ytimg.com/vi/AtgCcMjtqF0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD2LwD-aeBjScI5_trouLTGY_EDaw)\\
\\
46:39](https://www.youtube.com/watch?v=AtgCcMjtqF0)

### [I Spent a Year Replacing My Subscriptions. Here’s How.](https://www.youtube.com/watch?v=AtgCcMjtqF0)

Dammit Jeff

476K views • 3 weeks ago

[![](https://i.ytimg.com/vi/eUJdseG2j40/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLATdYwGLEpQVIYRuTqGJvmjm7W_EA)\\
\\
12:52](https://www.youtube.com/watch?v=eUJdseG2j40&pp=0gcJCcUKAYcqIYzv)

### [Area of a Triangle - 1/2 absin(C) - GCSE Higher Maths](https://www.youtube.com/watch?v=eUJdseG2j40&pp=0gcJCcUKAYcqIYzv)

1st Class Maths

113K views • 2 years ago

[![](https://i.ytimg.com/vi/NybHckSEQBI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLATu2i5-kjRS8ndwZ8dLPqbUpbJYw)\\
\\
12:07](https://www.youtube.com/watch?v=NybHckSEQBI)

### [Algebra Basics: What Is Algebra? - Math Antics](https://www.youtube.com/watch?v=NybHckSEQBI)

mathantics

10M views • 10 years ago

[![](https://i.ytimg.com/vi/7CQSzyi8UJE/hqdefault.jpg?v=6986f174&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCN3REOyRbF1XNG3Zaxro8lyw0o2g)\\
\\
LIVE](https://www.youtube.com/watch?v=7CQSzyi8UJE)

### [Cozy Outdoor Garden Cafe With Relaxing Jazz \| Peaceful Daytime Ambience for Focus, Study & Work](https://www.youtube.com/watch?v=7CQSzyi8UJE)

Tranquil Outdoor Jazz

1.4K watching

[![](https://i.ytimg.com/vi/3DF8LXZMwbE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDpxi8rOxUFnO3XmQP_WjEWTtjxgQ)\\
\\
1:12:13](https://www.youtube.com/watch?v=3DF8LXZMwbE)

### [Surah Al Waqiah سورة الواقعة \| A Peaceful Recitation to Calm Your Soul \| Al-Taqwa TV](https://www.youtube.com/watch?v=3DF8LXZMwbE)

Al-Taqwa TV

691K views • 1 year ago

[![](https://i.ytimg.com/vi/9yat2sSgupY/hqdefault.jpg?v=69bb1377&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBIWrmt98G0FQyZibmP3-ty1rEg9Q)\\
\\
LIVE](https://www.youtube.com/watch?v=9yat2sSgupY)

### [🔴 Mar 23's Top Cyber News NOW! - Ep 1094](https://www.youtube.com/watch?v=9yat2sSgupY)

Simply Cyber - Gerald Auger, PhD

330 watching

[![](https://i.ytimg.com/vi/xnL7K1dz3J8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDOJ3qYKOiz8dxH9uF-Jq77uTgxkw)\\
\\
48:13](https://www.youtube.com/watch?v=xnL7K1dz3J8)

### [FULL RACE: Tuscarora 50 \| Kubota High Limit Racing at Port Royal Speedway 9/7/2024](https://www.youtube.com/watch?v=xnL7K1dz3J8)

FloRacing

159K views • 1 year ago

[![](https://i.ytimg.com/vi/ylvTFvJvB84/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBK8smwkXzVE9jJrCbP2ervPKA3VQ)\\
\\
48:11](https://www.youtube.com/watch?v=ylvTFvJvB84)

### [Sen. Whitehouse to uncover connections between Trump, Russia, and Epstein.](https://www.youtube.com/watch?v=ylvTFvJvB84)

Senator Sheldon Whitehouse

3.5M views • Streamed 2 weeks ago

[![](https://lh3.googleusercontent.com/tfCPEs-U0EVnLDHk9DWPxln0hP_rF-U49JHxWqmeJ4mEkvPWjfuIi_XOfm8gv5zGWm8kh20TCA9L)\\
\\
35:40](https://www.youtube.com/watch?v=Yq65P1-veIk&pp=sAQB)

### [LeapFrog: The Letter Factory](https://www.youtube.com/watch?v=Yq65P1-veIk&pp=sAQB)

Children's • 2009

Free with ads

G

[![](https://i.ytimg.com/vi/YZTc5owqhiA/hqdefault.jpg?v=4&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC0bPzCEU3uwQfT5lihBMbZ7DT6iQ)\\
\\
LIVE](https://www.youtube.com/watch?v=YZTc5owqhiA&pp=0AUB)

### [3-23-26 Jim Coyle with Don Fischer, Greg Rakestraw, Dustin Dopirak 📱](https://www.youtube.com/watch?v=YZTc5owqhiA&pp=0AUB)

Indiana Sports Beat Radio with Jim Coyle

15 watching

[![](https://i.ytimg.com/vi/SSkk4fdw3Z8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDBuCn3_C7jq8axdeikuvY9COMn1A)\\
\\
21:12](https://www.youtube.com/watch?v=SSkk4fdw3Z8)

### [GettingToKnow FAITH RINGGOLD](https://www.youtube.com/watch?v=SSkk4fdw3Z8)

GettingtoKnow Inc

123K views • 5 years ago

[![](https://i.ytimg.com/vi/xOylTk5f8Q4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLALtAJsAht_8iTb6_UaWDQdgOijFA)\\
\\
1:35:55](https://www.youtube.com/watch?v=xOylTk5f8Q4)

### [Little People with a BIG Impact! 💥 \| Everyone Can Make A Difference \| VeggieTales](https://www.youtube.com/watch?v=xOylTk5f8Q4)

VeggieTales Official

298K views • 1 year ago

[![](https://lh3.googleusercontent.com/FMvWA24Z8Aarl6MroJVGKEP03hbSIKYCJI2i6I6EpF0ndQ-TqXiIxBmkB6ePnZnYABWKi1PkZO_p)\\
\\
1:25:29](https://www.youtube.com/watch?v=dp31p_b3BNw&pp=sAQB)

### [Surf's Up](https://www.youtube.com/watch?v=dp31p_b3BNw&pp=sAQB)

Family • 2007

Free with ads

PG

[![](https://i.ytimg.com/vi/7bGbY688wOM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLABJkyxTAi3jVkhgoqZr1dbnBfNmw)\\
\\
1:30:56](https://www.youtube.com/watch?v=7bGbY688wOM)

### [Películas Cristianas Infantiles \| José Hijo Amado](https://www.youtube.com/watch?v=7bGbY688wOM)

Películas Cristianas Infantiles

3.2M views • 3 years ago

[![](https://i.ytimg.com/vi/J-QjFrVR030/hqdefault.jpg?v=4&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC-NADxXV2wTmPjtmHz_JC0AzmsBA)\\
\\
LIVE](https://www.youtube.com/watch?v=J-QjFrVR030)

### [3-23-26 Jim Coyle with Don Fischer, Greg Rakestraw, Dustin Dopirak](https://www.youtube.com/watch?v=J-QjFrVR030)

Indiana Sports Beat Radio with Jim Coyle

57 watching

[![](https://i.ytimg.com/vi/gsi046VshZ4/hqdefault.jpg?v=68ff2d32&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAo6FYyDKDOE-TohAhhHZURj1NHdA)\\
\\
LIVE](https://www.youtube.com/watch?v=gsi046VshZ4&pp=0gcJCcUKAYcqIYzv)

### [Activate All 7 Chakras • Get Rid Of All Bad Energy • Boost Positive Energy](https://www.youtube.com/watch?v=gsi046VshZ4&pp=0gcJCcUKAYcqIYzv)

Balance Chakras Meditation

511 watching

[![](https://i.ytimg.com/vi/yLEkMR_MMwY/hqdefault.jpg?v=69c12474&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAYjopZLuOKFPVY-rbcCw2okADRKQ)\\
\\
LIVE](https://www.youtube.com/watch?v=yLEkMR_MMwY)

### [\[LIVE\] Pre-Market Prep – MAJOR GAP UP – US To Postpone Iran Strikes](https://www.youtube.com/watch?v=yLEkMR_MMwY)

Trade Brigade

4.4K watching

[![](https://i.ytimg.com/vi/4XeFxgD5ULA/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA9BNSvy7WFBy7tmKnuxL88qEoNEQ)\\
\\
23:56](https://www.youtube.com/watch?v=4XeFxgD5ULA&pp=0gcJCcUKAYcqIYzv)

### [Build ServiceNow Apps with AI: Claude Code + ServiceNow SDK Full Tutorial](https://www.youtube.com/watch?v=4XeFxgD5ULA&pp=0gcJCcUKAYcqIYzv)

Tushar Mishra

1.7K views • 7 days ago

[![](https://lh3.googleusercontent.com/Bx0VWNKoma6YK9D11PZU1WuRom1CaANbIgOJfe3kC1umKbYNf9K-E7UZ2gdObPJ5isncwidTXhcrSQ)\\
\\
2:04:36](https://www.youtube.com/watch?v=B_rgpR77Ee4&pp=sAQB)

### [Oblivion](https://www.youtube.com/watch?v=B_rgpR77Ee4&pp=sAQB)

Action & adventure • 2013

Free with ads

PG-13

[![](https://i.ytimg.com/vi/JihZB7A6bb0/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLD1Ct5JR4VNGKpn_Ts3v9IRhPC0XQ)\\
\\
1:05:57](https://www.youtube.com/watch?v=JihZB7A6bb0)

### [A pártfinanszírozás sötét oldala \#válságstáb](https://www.youtube.com/watch?v=JihZB7A6bb0)

VÁLSÁGSTÁB and fókuszcsoport

5.3K views • 8 hours ago

New

[![](https://i.ytimg.com/vi/PbQIydOF8Bk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCpFq1tlzY7XdsqIA65QyJiR0FfRg)\\
\\
13:34](https://www.youtube.com/watch?v=PbQIydOF8Bk)

### [‘A defense of America’: ‘No Kings’ protests to fight against Trump’s agenda ‘terrorizing’ the U.S.](https://www.youtube.com/watch?v=PbQIydOF8Bk)

MS NOW

246K views • 23 hours ago

New

[![](https://i.ytimg.com/vi/wseCMWAcZSU/hqdefault.jpg?v=69a2b0ba&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBpwzkVXThdVwnCPAZkPd012BLEWg)\\
\\
LIVE](https://www.youtube.com/watch?v=wseCMWAcZSU)

### [🔴Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \| مكه المكرمه](https://www.youtube.com/watch?v=wseCMWAcZSU)

Al Qari Studio

738 watching

[![](https://i.ytimg.com/vi/PQOwpjZXzMo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDN9mrlP5nq21h6i4dZKSo2uusVeg)\\
\\
13:58](https://www.youtube.com/watch?v=PQOwpjZXzMo&pp=ugUEEgJlbg%3D%3D)

### [Is HexStrike the BEST AI MCP for Hacking? (Bug Bounty Tested)](https://www.youtube.com/watch?v=PQOwpjZXzMo&pp=ugUEEgJlbg%3D%3D)

ZeroDay Gym

50K views • 2 months ago

[![](https://lh3.googleusercontent.com/-uvc79meLi56zvN_o7HesZ2MJdJ2DR6pQ9r2hhTUluBvz_kyhkCLjdtft6hiYa5LyQNTBViwq999)\\
\\
2:56:13](https://www.youtube.com/watch?v=kRzmxox0L0k&pp=sAQB)

### [A Bridge Too Far](https://www.youtube.com/watch?v=kRzmxox0L0k&pp=sAQB)

Action & adventure • 1977

Free with ads

PG

[![](https://lh3.googleusercontent.com/EPpAypxccMvZapAbCDTp4NKYxBjf704FRxi2uTwCWaznov4jE0GE4zRMHjMEk_pCKsgvXdWlWFLN)\\
\\
1:32:28](https://www.youtube.com/watch?v=6-yhHfuw1kI&pp=sAQB)

### [Flowstate: The FPV Drone Documentary](https://www.youtube.com/watch?v=6-yhHfuw1kI&pp=sAQB)

Documentary • 2022

Free with ads

TV-PG

[![](https://i.ytimg.com/vi/8rTT6yREsdQ/hqdefault.jpg?v=69b3c9ea&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDtbp2hViAPPcFoTCMy8TmgbDuafA)\\
\\
LIVE](https://www.youtube.com/watch?v=8rTT6yREsdQ)

### [Soothing Music + Bamboo Water Sounds 🌿 Calming Music for Sleep, Relaxation, Spa, Deep Healing Music](https://www.youtube.com/watch?v=8rTT6yREsdQ)

Harmony Calm Music

47 watching

[![](https://lh3.googleusercontent.com/FcSMc9gJ_sbuQCY83ltUn4F3K5wfNPY18cmN3I2ciJOWQqVPh6nFnnuJDKUIkwLyP8gJzKa0-lsp)\\
\\
2:07:31](https://www.youtube.com/watch?v=Z5bwEvL58Mo&pp=sAQB)

### [Jupiter Ascending](https://www.youtube.com/watch?v=Z5bwEvL58Mo&pp=sAQB)

Action & adventure • 2015

Free with ads

PG-13

[![](https://lh3.googleusercontent.com/e57FF-zqt3PncVGS19jVCQzMhj7-yrEdVoiAORSRTVSJiFdVMaSIIqx0zrFh6MeF1a8syvDMp_0)\\
\\
1:26:35](https://www.youtube.com/watch?v=lSfqPj7PpVc&pp=sAQB)

### [Cryptopia: Bitcoin, Blockchains, and the Future of the Internet](https://www.youtube.com/watch?v=lSfqPj7PpVc&pp=sAQB)

Documentary • 2021

Free with ads

TV-PG

[![](https://lh3.googleusercontent.com/0L-jq979WMWGpFa922B48uOed48YmLi6gbKdfHBuTwodmRmKAYgOD2bf2Dy-0cOk_hYNt3S3NKsM)\\
\\
1:31:12](https://www.youtube.com/watch?v=I1smvp5vjwo&pp=sAQB)

### [Joe Dirt (2001)](https://www.youtube.com/watch?v=I1smvp5vjwo&pp=sAQB)

Comedy • 2001

Free with ads

PG-13

[![](https://lh3.googleusercontent.com/bPwZTxCr-FmHEqdrRe9U1-rvANfJZc4UqoZxKlGwFURKOJHmI93CYv6EekFwqzudHD9c-ZSiRbir)\\
\\
1:35:28](https://www.youtube.com/watch?v=wdud3C_UmNA&pp=sAQB)

### [I.S.S.](https://www.youtube.com/watch?v=wdud3C_UmNA&pp=sAQB)

Science fiction • 2024

Free with ads

R

New

[![](https://i.ytimg.com/vi/KUjjQe0gSNg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAJwfVACAOxU2h1uOckuJ6eRPlS7Q)\\
\\
27:34](https://www.youtube.com/watch?v=KUjjQe0gSNg&pp=ugUHEgVlbi1VUw%3D%3D)

### ['Stupid' Trump ROLLED OVER For Netanyahu, Says Dem Senator](https://www.youtube.com/watch?v=KUjjQe0gSNg&pp=ugUHEgVlbi1VUw%3D%3D)

Zeteo

661K views • 1 day ago

New

[![](https://i.ytimg.com/vi/aircAruvnKk/hqdefault.jpg?sqp=-oaymwEWCKgBEF5IWvKriqkDCQgBFQAAiEIYAQ==&rs=AOn4CLCijkTv7yK6OaSODOOfVy4v7fI_-A)\\
\\
27 videos](https://www.youtube.com/watch?v=aircAruvnKk&list=PLZHQObOWTQDN52m7Y21ePrTbvXkPaWVSg)

### [Explainers](https://www.youtube.com/watch?v=aircAruvnKk&list=PLZHQObOWTQDN52m7Y21ePrTbvXkPaWVSg)

[3Blue1Brown](https://www.youtube.com/@3blue1brown) • [Playlist](https://www.youtube.com/@3blue1brown)

[View full playlist](https://www.youtube.com/playlist?list=PLZHQObOWTQDN52m7Y21ePrTbvXkPaWVSg)

[![](https://i.ytimg.com/vi/VFnr0lwwGuQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLASCw-G8InYQZt5OHRhuQN1UCpWYQ)\\
\\
19:02](https://www.youtube.com/watch?v=VFnr0lwwGuQ)

### [Make Windows Terminal look clean with Oh My Posh](https://www.youtube.com/watch?v=VFnr0lwwGuQ)

Kayla Cinnamon ☕

4.6K views • 3 weeks ago

[![](https://i.ytimg.com/vi/We7BZVKbCVw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCnKgjJY-m53x822jmAo0dZoR0qyA)\\
\\
1:27:45](https://www.youtube.com/watch?v=We7BZVKbCVw)

### [Head of Claude Code: What happens after coding is solved \| Boris Cherny](https://www.youtube.com/watch?v=We7BZVKbCVw)

Lenny's Podcast

415K views • 1 month ago

[![](https://i.ytimg.com/vi/xNb_hC9Zzlk/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBqC-LA-_25A6HZ0eizrcVWjirrQA)\\
\\
11:04](https://www.youtube.com/watch?v=xNb_hC9Zzlk&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

### [Andrew Yang on AI's impact on jobs, Anthropic's battle with the Pentagon and NYC Mayor Mamdani](https://www.youtube.com/watch?v=xNb_hC9Zzlk&pp=ugUEEgJlbtIHCQnFCgGHKiGM7w%3D%3D)

CNBC Television

496K views • 11 days ago

[![](https://i.ytimg.com/vi/XhASEIFbdkI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCai4iMp4qpvqjuVTjDKYe7FlvV6A)\\
\\
1:03:29](https://www.youtube.com/watch?v=XhASEIFbdkI&list=RDXhASEIFbdkI&start_radio=1&pp=oAcB)

### [IN HIS PRESENCE - Soaking worship instrumental \| Prayer and Devotional](https://www.youtube.com/watch?v=XhASEIFbdkI&list=RDXhASEIFbdkI&start_radio=1&pp=oAcB)

Central Record

2.8M views • 1 year ago

[![](https://lh3.googleusercontent.com/BkBdTViYnAIan1AKB2EgJ3HdwxbyoIBMO2fpxmVOTi54NMLzsa3dglN_teNDJbfiOPmJBPwe3FZb)\\
\\
2:06:39](https://www.youtube.com/watch?v=Y7Me3H3vqVE&pp=sAQB)

### [What Women Want](https://www.youtube.com/watch?v=Y7Me3H3vqVE&pp=sAQB)

Comedy • 2000

Free with ads

PG-13

[![](https://i.ytimg.com/vi/qDU9tHdvDhQ/hqdefault.jpg?v=69ae9af4&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAQz7RgZ5u5i6G_mwPZCmAFQ4R_jQ)\\
\\
LIVE](https://www.youtube.com/watch?v=qDU9tHdvDhQ)

### [🔴 LIVE Soccer Games! \| Supa Strikas vs Grimm FC! \| Football Cartoon for Kids](https://www.youtube.com/watch?v=qDU9tHdvDhQ)

The Supa Strikas - Kids Soccer Cartoon

610 watching

[![](https://i.ytimg.com/vi/g7S_hm4l-N4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC5IG-xcJTbxQ88JziFK9NQhJ6L5g)\\
\\
2:00:45](https://www.youtube.com/watch?v=g7S_hm4l-N4)

### [سورة البقرة كاملة للشيخ د.ياسر الدوسري \| Surah AlBaqarah](https://www.youtube.com/watch?v=g7S_hm4l-N4)

أ.د ياسر بن راشد الدوسري

3.9M views • Streamed 1 year ago

[![](https://i.ytimg.com/vi/shJcbG18OAg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAlLVqfUX02lPQ7V2Dp4A6mAm0jlw)\\
\\
19:11](https://www.youtube.com/watch?v=shJcbG18OAg)

### [Nancy Guthrie Case Takes Tragic Turn....? \| TMZ](https://www.youtube.com/watch?v=shJcbG18OAg)

TMZ

586K views • 1 day ago

New

[![](https://lh3.googleusercontent.com/6RKqUiioX8sVo5_IWBgINk_ooP-RbT7gaPAA1VMxISLhMyMSwsFcXESxomOGV1fk7BRoEQk-mVAs1w)\\
\\
45:09](https://www.youtube.com/watch?v=wF1sAryd5lc&pp=sAQB0gcJCcUKAYcqIYzv)

### [Flight Photographers](https://www.youtube.com/watch?v=wF1sAryd5lc&pp=sAQB0gcJCcUKAYcqIYzv)

Documentary • 2026

Free with ads

TV-PG

[![](https://i.ytimg.com/vi/ui2nX_uCL0s/hqdefault.jpg?v=69acdcd0&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAYQcuD_eBpZNCQDdMnJGRslOJJGw)\\
\\
LIVE](https://www.youtube.com/watch?v=ui2nX_uCL0s)

### [🔴 LIVE Red Screen 24/7 \| Pure Solid Red Background • Ambient Color Stream](https://www.youtube.com/watch?v=ui2nX_uCL0s)

Danny Rain Natural

211 watching

[![](https://i.ytimg.com/vi/jq_LZ1RFPfU/hqdefault.jpg?sqp=-oaymwEWCKgBEF5IWvKriqkDCQgBFQAAiEIYAQ==&rs=AOn4CLBsTsgbgclcjrhoyghzHJfO6_NL7Q)\\
\\
10 videos](https://www.youtube.com/watch?v=jq_LZ1RFPfU&list=PLOspHqNVtKADkWLFt9OcziQF7EatuANSY)

### [Cybersecurity Architecture Series](https://www.youtube.com/watch?v=jq_LZ1RFPfU&list=PLOspHqNVtKADkWLFt9OcziQF7EatuANSY)

[IBM Technology](https://www.youtube.com/@IBMTechnology) • [Playlist](https://www.youtube.com/@IBMTechnology)

[View full playlist](https://www.youtube.com/playlist?list=PLOspHqNVtKADkWLFt9OcziQF7EatuANSY)

[![](https://i.ytimg.com/vi/SxF6NazR35M/hqdefault.jpg?v=1&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDDP_udJrvxvVahrRQq8sSVJNqadw)\\
\\
LIVE](https://www.youtube.com/watch?v=SxF6NazR35M&pp=0gcJCcUKAYcqIYzv)

### [AI Morning Club – Your Daily AI Advantage](https://www.youtube.com/watch?v=SxF6NazR35M&pp=0gcJCcUKAYcqIYzv)

Perry Belcher

5 watching

[![](https://lh3.googleusercontent.com/z-aa-mMdx-3Sr-9sl3uHow7zRJ4Chn397kUfnPiuGwks8ss-zXwtRHjDAWRJxO66KMuDAbmkfdM9)\\
\\
1:45:25](https://www.youtube.com/watch?v=5T_CqqjOPDc&pp=sAQB0gcJCcUKAYcqIYzv)

### [Hackers](https://www.youtube.com/watch?v=5T_CqqjOPDc&pp=sAQB0gcJCcUKAYcqIYzv)

Drama • 1995

Free with ads

PG-13

[![](https://i.ytimg.com/vi/CuaYKC5Ao8M/hqdefault.jpg?v=69bd7719&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB3pUl2HIqCZYX9UKU1ohx4nm7Tzw)\\
\\
LIVE](https://www.youtube.com/watch?v=CuaYKC5Ao8M&pp=0gcJCcUKAYcqIYzv)

### [Monday 3/23 ESPN Chicago LIVE!](https://www.youtube.com/watch?v=CuaYKC5Ao8M&pp=0gcJCcUKAYcqIYzv)

ESPN Chicago

997 watching

[![](https://lh3.googleusercontent.com/nksgcDtShU4Fg7xulLE99MlYCpH_ypCf0VMOx_2NYDRd-UpXOlih6jfSgsF_xtcG43DihAf-IimE)\\
\\
1:26:19](https://www.youtube.com/watch?v=TUqku2o3pzY&pp=sAQB)

### [Vitalik: An Ethereum Story](https://www.youtube.com/watch?v=TUqku2o3pzY&pp=sAQB)

Documentary • 2025

Free with ads

TV-PG

[![](https://i.ytimg.com/vi/plzInmfR68c/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDST6Jq6xmUM8E2rcLlltv7N1YXIg)\\
\\
1:20:00](https://www.youtube.com/watch?v=plzInmfR68c)

### [🔴 TIME TRAVEL Bible Adventures PLUS 8 Bible Stories About Jesus! \| Bible Stories for Kids](https://www.youtube.com/watch?v=plzInmfR68c)

Minno - Bible Stories for Kids

225K views • Streamed 2 years ago

[![](https://i.ytimg.com/pl_c/PLrZ2zKOtC_-C4rWfapgngoe9o2-ng8ZBr/studio_square_thumbnail.jpg?sqp=CLXghM4G-oaymwEICKoDEPABSFqi85f_AwYI2K_3zQY=&rs=AOn4CLDUurpX3uYZ9LMPECJG7z-GL5ZebA)\\
\\
34 lessons](https://www.youtube.com/watch?v=WKb3mRkgTwg&list=PLrZ2zKOtC_-C4rWfapgngoe9o2-ng8ZBr)

### [Learn Autodesk Fusion 360 in 30 Days for Complete Beginners! 2026 EDITION](https://www.youtube.com/watch?v=WKb3mRkgTwg&list=PLrZ2zKOtC_-C4rWfapgngoe9o2-ng8ZBr)

[Product Design Online](https://www.youtube.com/@ProductDesignOnline) • [Course](https://www.youtube.com/@ProductDesignOnline)

Updated yesterday

[View full course](https://www.youtube.com/playlist?list=PLrZ2zKOtC_-C4rWfapgngoe9o2-ng8ZBr)

[![](https://lh3.googleusercontent.com/Yvt9d22SNRXW43NGIZu4MIVA2M-RJaMDqIq6cUb5tOFOqyawvHTWoZWJZKsK6DeMBacRyZ4x0Vg)\\
\\
1:04:30](https://www.youtube.com/watch?v=dQ8wVeJkvco&pp=sAQB)

### [How Thoughts Become Things](https://www.youtube.com/watch?v=dQ8wVeJkvco&pp=sAQB)

Documentary • 2020

Free with ads

TV-PG

[![](https://lh3.googleusercontent.com/BUkiQv3n-jQH-rRJvO2F6YDp5VU2mJuRYnVi_slHXWDZPkFP3ANzXYbS1VJo3jPFBKQR-byflew)\\
\\
1:44:16](https://www.youtube.com/watch?v=WUWCQ8S6D3k&pp=sAQB)

### [Betting on Zero](https://www.youtube.com/watch?v=WUWCQ8S6D3k&pp=sAQB)

Documentary • 2017

Free with ads

TV-PG

[![](https://lh3.googleusercontent.com/4b1yqeXwooUd65bUjydgx7hsr6SOpKxIUIfmoC4HDuk226JwIKpdRwnEiVh4dwqSLjXP-zxQSe_g)\\
\\
41:32](https://www.youtube.com/watch?v=KVi_rvV982o&pp=sAQB0gcJCcUKAYcqIYzv)

### [The Millennial Dream](https://www.youtube.com/watch?v=KVi_rvV982o&pp=sAQB0gcJCcUKAYcqIYzv)

Documentary • 2017

Free with ads

TV-PG

[![](https://lh3.googleusercontent.com/spf8O9m4Pcf0r1JpBfzAagky-C_7UMAe4jvVQXeGIhByaLy5izo0BbKzXBYv7YUsOh3epOmGlfZj)\\
\\
1:24:10](https://www.youtube.com/watch?v=eCUkmaTXzE4&pp=sAQB)

### [I Am Chris Farley](https://www.youtube.com/watch?v=eCUkmaTXzE4&pp=sAQB)

Documentary • 2015

Free with ads

TV-14

[![](https://i.ytimg.com/vi/mOqhhDXUgUo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDKMAkElZCs9phk0cNri1P3hTSSfQ)\\
\\
24:28](https://www.youtube.com/watch?v=mOqhhDXUgUo&pp=ugUEEgJlbg%3D%3D)

### [Master 80% of Antigravity in 25 minutes (You’ll beat Everyone)](https://www.youtube.com/watch?v=mOqhhDXUgUo&pp=ugUEEgJlbg%3D%3D)

Michele Torti

146K views • 2 months ago

[![](https://i.ytimg.com/vi/_Dz2e21tSzI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA_S76BKV9SS0gM0X5aujwbcVIYjw)\\
\\
35:39](https://www.youtube.com/watch?v=_Dz2e21tSzI&pp=ugUEEgJlbg%3D%3D)

### [GNOME 50, Manjaro 2.0 Manifesto, GIMP 3.2, Blender 5.1, Fedora Asahi, Samba, & more Linux news](https://www.youtube.com/watch?v=_Dz2e21tSzI&pp=ugUEEgJlbg%3D%3D)

Michael Tunnell

13K views • 1 day ago

New

[![](https://i.ytimg.com/vi/K7P3bR33Hhc/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCC1kV0g8MpjsCsOPO1gk-LMSmzAw)\\
\\
49:42](https://www.youtube.com/watch?v=K7P3bR33Hhc)

### [Ultimate homelab telephony box?](https://www.youtube.com/watch?v=K7P3bR33Hhc)

clabretro

34K views • 2 days ago

New

[![](https://lh3.googleusercontent.com/1JEZGmuQ0w-8k7kDF3L-fzzWRbsgTv2ziSLO7p2RQuTnX-m8b66Ks0Ill9iKmduq-WbOq7MlVkcD)\\
\\
1:30:14](https://www.youtube.com/watch?v=EmcDKI95znQ&pp=sAQB)

### [Steep](https://www.youtube.com/watch?v=EmcDKI95znQ&pp=sAQB)

Action & adventure • 2007

Free with ads

PG-13

[![](https://i.ytimg.com/vi/F3hbgqgGev4/hqdefault.jpg?v=69c01c7c&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA7L0ymv9CCn7wtYWF4y11gl5iuWg)\\
\\
LIVE](https://www.youtube.com/watch?v=F3hbgqgGev4)

### [MONDAY, 23RD MARCH 2026 \|\| SPEAK INTO YOUR MONDAY BEFORE THE ENEMY DOES \|\| APOSTLE JOSHUA SELMAN](https://www.youtube.com/watch?v=F3hbgqgGev4)

DAILY PRAYERS BY APOSTLE JOSHUA SELMAN

1.3K watching

[![](https://i.ytimg.com/vi/bVU5pGUNbAU/hqdefault.jpg?v=69bffb15&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAB-cn7SATUmd_J5AkpZCm_fDM7ig)\\
\\
LIVE](https://www.youtube.com/watch?v=bVU5pGUNbAU)

### [23/03/2026 Live Japji Sahib \| ਨਿੱਤਨੇਮ ਜਪੁਜੀ ਸਾਹਿਬ ਜੀ \| जपजी साहिब पाठ \| japji sahib Full Fast Path](https://www.youtube.com/watch?v=bVU5pGUNbAU)

Gurbani live 24 TV

67 watching

[![](https://i.ytimg.com/vi/OdKMgTzpkO8/hqdefault.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAHwAQH4Af4JgALQBYoCDAgAEAEYESByKEEwDw==&rs=AOn4CLBpcYdzPDYpN0tFUYp2xcHT2vBXIg)\\
\\
1:48:19](https://www.youtube.com/watch?v=OdKMgTzpkO8&pp=sAQB)

### [The Bitcoin Field Guide: Understanding Crypto Currency](https://www.youtube.com/watch?v=OdKMgTzpkO8&pp=sAQB)

Documentary • 2022

Free with ads

TV-14

[![](https://i.ytimg.com/vi/iuUrdFCX6Xw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCBi1OJXH0yaI4U1B1skuvc2TEqjA)\\
\\
7:33](https://www.youtube.com/watch?v=iuUrdFCX6Xw&pp=ugUEEgJlbg%3D%3D)

### [The U.S. and Mexico Kick Off NAFTA Talks \|\| Peter Zeihan](https://www.youtube.com/watch?v=iuUrdFCX6Xw&pp=ugUEEgJlbg%3D%3D)

Zeihan on Geopolitics

20K views • 3 hours ago

New

[![](https://lh3.googleusercontent.com/EF5ZbdgmmMsdVEu7d1z9kRrZl-FuDiW1p9IU7LctQOJuQEivsJ-aY5tbzytFA6mwTZZ5CSY30luK)\\
\\
51:46](https://www.youtube.com/watch?v=zw_ab7uoDFA&pp=sAQB)

### [Altitude Adjustment](https://www.youtube.com/watch?v=zw_ab7uoDFA&pp=sAQB)

Documentary • 2015

Free with ads

TV-PG

[![](https://i.ytimg.com/vi/gRP93rfiies/hqdefault.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAHwAQH4Af4JgALQBYoCDAgAEAEYZSBkKFYwDw==&rs=AOn4CLC71R1CSWrIscIjuT4r1W-Mu1oG1w)\\
\\
39:04](https://www.youtube.com/watch?v=gRP93rfiies&pp=ugUHEgVlbi1VUw%3D%3D)

### [What the Heck Just Happened?](https://www.youtube.com/watch?v=gRP93rfiies&pp=ugUHEgVlbi1VUw%3D%3D)

Heather Cox Richardson

361K views • Streamed 1 day ago

New

[![](https://i.ytimg.com/vi/KkE5zUTJVZs/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBOQU6DzT33ixLYrcJdBUo7FwMS4A)\\
\\
15:32](https://www.youtube.com/watch?v=KkE5zUTJVZs&pp=0gcJCcUKAYcqIYzv)

### [Jesus Wept - Bishop Barron's Sunday Sermon](https://www.youtube.com/watch?v=KkE5zUTJVZs&pp=0gcJCcUKAYcqIYzv)

Bishop Robert Barron

189K views • 1 day ago

New

[![](https://i.ytimg.com/vi/IN0_BSwxfS8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCfcqCByfUjrZnWku3BoRY4c7yd6w)\\
\\
28:30](https://www.youtube.com/watch?v=IN0_BSwxfS8)

### [Xiaomi MiMo V2 Pro Is INSANE – Testing A NEW Frontier Model!](https://www.youtube.com/watch?v=IN0_BSwxfS8)

Bijan Bowen

13K views • 1 day ago

New

[![](https://i.ytimg.com/vi/jKNdwZf_lrI/hqdefault.jpg?v=699db3ae&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDBz3RKlHFKz3cw4dH3yhIpWIYwIg)\\
\\
LIVE](https://www.youtube.com/watch?v=jKNdwZf_lrI)

### [(No Ads) Calm Morning Music 🌿 Positive Energy Start & Gentle Stress Relief for a Peaceful Day](https://www.youtube.com/watch?v=jKNdwZf_lrI)

MrFirstLight88

483 watching

[![](https://i.ytimg.com/vi/iKZtz27o6ns/hqdefault.jpg?v=28f42&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCvzLyazF6Ps9v_Hbo3BRepYOuZ8Q)\\
\\
LIVE](https://www.youtube.com/watch?v=iKZtz27o6ns)

### [The Water Street Inn Live Stream - Ephraim, WI](https://www.youtube.com/watch?v=iKZtz27o6ns)

The Water Street Inn - Ephraim

5 watching

[![](https://i.ytimg.com/vi/Q7sXJTBF4CE/hqdefault.jpg?v=69800b14&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB8wYvmmApuTN30d9D0HvNZ1K5xKw)\\
\\
LIVE](https://www.youtube.com/watch?v=Q7sXJTBF4CE)

### [Musica para orar o meditar sin anuncios intermedios](https://www.youtube.com/watch?v=Q7sXJTBF4CE)

PIANO CON AMOR

294 watching

[![](https://lh3.googleusercontent.com/-p0Ow3F95cOuejcjb3ECAqtTtuJ__mdchXVcb2YXWLg3rw5FkjTQrf-vld1a3u9KKn0N-uIVAAsB)\\
\\
1:35:31](https://www.youtube.com/watch?v=Mrje-m01kI8&pp=sAQB)

### [Finding the Money](https://www.youtube.com/watch?v=Mrje-m01kI8&pp=sAQB)

Documentary • 2024

Free with ads

TV-PG

[![](https://lh3.googleusercontent.com/-luyKaRxdG96kO1xHS9-M928zdIE-MOuR43uznO94mPMvoUWKencJLKl0HayNPBz8k08fs0HewTEbQ)\\
\\
1:23:41](https://www.youtube.com/watch?v=6jSm9vTBGKU&pp=sAQB)

### [Banking on Bitcoin](https://www.youtube.com/watch?v=6jSm9vTBGKU&pp=sAQB)

Documentary • 2017

Free with ads

TV-PG

[![](https://i.ytimg.com/vi/RD65hXCZ8Yo/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCMomnApGe169P17UGYZyaAkzv7pw)\\
\\
17:32](https://www.youtube.com/watch?v=RD65hXCZ8Yo)

### [Vision Agent Explained: I Built an AI That Sees Your Screen 🤯 (Full Demo + Giveaway)](https://www.youtube.com/watch?v=RD65hXCZ8Yo)

TubeGuruji

4.3K views • 2 days ago

New

[![](https://i.ytimg.com/vi/1CeX-Bwv-WY/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBJVSCSEesU6F5-37I8mtmH80QVnQ)\\
\\
12:08](https://www.youtube.com/watch?v=1CeX-Bwv-WY&pp=ugUEEgJlbg%3D%3D)

### [Antigravity Cluster: Google's NEW Free Antigravity Feature MAKES it INSANE!](https://www.youtube.com/watch?v=1CeX-Bwv-WY&pp=ugUEEgJlbg%3D%3D)

AICodeKing

1.8K views • 3 hours ago

New

[![](https://i.ytimg.com/vi/z13ltuLZMOI/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLB38eAFhkye9nfa7ogCn4S1WFwrRg)\\
\\
2:06:35](https://www.youtube.com/watch?v=z13ltuLZMOI)

### [Алексей Венедиктов. Отключения интернета \- это удар по верному Путину электорату.](https://www.youtube.com/watch?v=z13ltuLZMOI)

Yulia Latynina

84K views • Streamed 19 hours ago

New

[![](https://i.ytimg.com/vi/nKVZBKoB6P4/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCchWRQnbhHe_1OSf3WTIYWac8J_w)\\
\\
27:04](https://www.youtube.com/watch?v=nKVZBKoB6P4&pp=ugUEEgJlbg%3D%3D)

### [Agent Skills in Xcode - Build better SwiftUI apps with AI agents](https://www.youtube.com/watch?v=nKVZBKoB6P4&pp=ugUEEgJlbg%3D%3D)

Paul Hudson

14K views • 11 days ago

[![](https://i.ytimg.com/vi/03LivdDST6s/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLAIIauZOaGRzCIx43GYd5PylmyPZA)\\
\\
54:39](https://www.youtube.com/watch?v=03LivdDST6s&pp=ugUEEgJlbg%3D%3D)

### [We’re Selling Black Market Movies… (Retro Rewind Part 3)](https://www.youtube.com/watch?v=03LivdDST6s&pp=ugUEEgJlbg%3D%3D)

CaseOh

376K views • 1 day ago

New

[![](https://i.ytimg.com/vi/YAkygV00AkQ/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCagSycismU9fXsdjb1QlZJ6mejuw)\\
\\
46:22](https://www.youtube.com/watch?v=YAkygV00AkQ)

### [Kulthum ibn al-Hadm (ra) & Sa'ad ibn Khaythamah (ra): The Hosts of Masjid Quba \| Dr. Omar Suleiman](https://www.youtube.com/watch?v=YAkygV00AkQ)

Yaqeen Institute

264K views • Streamed 3 years ago

[![](https://i.ytimg.com/vi/fVJd_YRMhxM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLA-TUg1uoyd6nrvb-5xe5ZQjcaF1w)\\
\\
35:23](https://www.youtube.com/watch?v=fVJd_YRMhxM&pp=ugUEEgJlbg%3D%3D)

### [REVALUE TIME ON THE CURRENCY! A MESSAGE FROM GOD – MARCH 22, 2026](https://www.youtube.com/watch?v=fVJd_YRMhxM&pp=ugUEEgJlbg%3D%3D)

Declaring Your Destiny Intl.

4.4K views • 2 hours ago

New

[![](https://i.ytimg.com/vi/OnAMiiIfxzk/hqdefault.jpg?v=69b2f631&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCmpL-HYYzo1Q-IXOANuU_nSKjChQ)\\
\\
LIVE](https://www.youtube.com/watch?v=OnAMiiIfxzk)

### [🔴 Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \| مكه المكرمه](https://www.youtube.com/watch?v=OnAMiiIfxzk)

Daily Quran Message

253 watching

[![](https://i.ytimg.com/vi/dBIlCD_JF9Q/hqdefault.jpg?sqp=-oaymwEWCKgBEF5IWvKriqkDCQgBFQAAiEIYAQ==&rs=AOn4CLDxM-rxS7VdPrlPSjthxYBeaNWRxQ)\\
\\
35 lessons](https://www.youtube.com/watch?v=dBIlCD_JF9Q&list=PLJ6MxZJs9Ht8ds7Bg_-Rit-WxqjHctPCB)

### [Target Grade 7/6](https://www.youtube.com/watch?v=dBIlCD_JF9Q&list=PLJ6MxZJs9Ht8ds7Bg_-Rit-WxqjHctPCB)

[1st Class Maths](https://www.youtube.com/@1stClassMaths) • [Course](https://www.youtube.com/@1stClassMaths)

[View full course](https://www.youtube.com/playlist?list=PLJ6MxZJs9Ht8ds7Bg_-Rit-WxqjHctPCB)

[![](https://i.ytimg.com/vi/e_iNf2jf8Kg/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDMUrRhKklaiSM5vDs_-4AzfBapNQ)\\
\\
19:24](https://www.youtube.com/watch?v=e_iNf2jf8Kg)

### [One CLI to Replace Every Tool Schema](https://www.youtube.com/watch?v=e_iNf2jf8Kg)

KTG Analysis

2.3K views • 2 days ago

New

[![](https://i.ytimg.com/vi/qse_Gj0ZeGQ/hqdefault.jpg?v=699dee00&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDRzwY9QyeXK8EGABCACJ8yyNt29g)\\
\\
LIVE](https://www.youtube.com/watch?v=qse_Gj0ZeGQ)

### [🔴 Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \| مكه المكرمه](https://www.youtube.com/watch?v=qse_Gj0ZeGQ)

Ayat-e-Quran

12 watching

[![](https://i.ytimg.com/vi/qxNCJHIWV_w/hqdefault.jpg?v=6945043d&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDUlFPr4QQW_uGqFVmTY7bMk1djOg)\\
\\
LIVE](https://www.youtube.com/watch?v=qxNCJHIWV_w)

### [CORONILLA A LA DIVINA MISERICORDIA MISTERIOS DOLOROSOS ROSARIO - CORONILLA A LA DIVINA MISERICORDIA](https://www.youtube.com/watch?v=qxNCJHIWV_w)

La Felicidad De Dios

185 watching

[![](https://i.ytimg.com/vi/zDQIWfvwBIs/hqdefault.jpg?v=69b2a86a&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBDUCNJ_k34rY2p-VBZYb2U3ccjvQ)\\
\\
LIVE](https://www.youtube.com/watch?v=zDQIWfvwBIs)

### [🔴 Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \| مكه المكرمه](https://www.youtube.com/watch?v=zDQIWfvwBIs)

Daily Quran Reminder

1.8K watching

[![](https://i.ytimg.com/vi/3Ne7gFqsWt8/hqdefault.jpg?v=69b6a200&sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDrgb2PPc6dklcS2n5ItnJM82fXnw)\\
\\
LIVE](https://www.youtube.com/watch?v=3Ne7gFqsWt8)

### [🔴 Makkah Live \| مكة مباشر \| الحرم المكي مباشر \| قناة القران الكريم السعودية مباشر \|مكه المكرمه مباشر](https://www.youtube.com/watch?v=3Ne7gFqsWt8)

Qari Inam ur Rehman

320 watching

[![](https://i.ytimg.com/vi/g7V0UJv9gT4/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYZSBlKGUwDw==&rs=AOn4CLBOOYCdEjtcXIEZ_kOwmIlzwEITWw)\\
\\
Shorts](https://www.youtube.com/shorts/g7V0UJv9gT4)

### [Autoresearch: AI agents conducting deep learning research completely on their own](https://www.youtube.com/shorts/g7V0UJv9gT4)

Github Awesome

49K views • 2 weeks ago

[![](https://i.ytimg.com/vi/Tv2-g8PrT9c/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYQSBVKGUwDw==&rs=AOn4CLBICKe8HzNQ7kIukPYu4W28sHB-7Q)\\
\\
Shorts](https://www.youtube.com/shorts/Tv2-g8PrT9c)

### [Andrej Karpathy just dropped AgentHub! It’s literally GitHub, but redesigned entirely for AI agents](https://www.youtube.com/shorts/Tv2-g8PrT9c)

Github Awesome

27K views • 13 days ago

[![](https://i.ytimg.com/vi/v2YcbzghnPA/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYZSBlKGUwDw==&rs=AOn4CLAL7Erwc_oIxJRxziOtZLXGSdSh7Q)\\
\\
Shorts](https://www.youtube.com/shorts/v2YcbzghnPA)

### [Ghostling: A Minimal Terminal Embedding Engine](https://www.youtube.com/shorts/v2YcbzghnPA)

Github Awesome

9.1K views • 1 day ago

New

[![](https://i.ytimg.com/vi/dKQfCyDCq3U/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYKyBYKHIwDw==&rs=AOn4CLDps5iW7rvvaAVaf3vuzbzvE1s5BA)\\
\\
Shorts](https://www.youtube.com/shorts/dKQfCyDCq3U)

### [Skales: This AI App Has a Lizard Mascot](https://www.youtube.com/shorts/dKQfCyDCq3U)

Github Awesome

60K views • 4 days ago

New

[![](https://i.ytimg.com/vi/BYUvJl6Gfxk/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYWyBiKGUwDw==&rs=AOn4CLBjacaNokRVJxSLmam2ac9Pj-PK6A)\\
\\
Shorts](https://www.youtube.com/shorts/BYUvJl6Gfxk)

### [mcp2cli: It instantly converts any MCP server or OpenAPI spec into a dynamic CLI](https://www.youtube.com/shorts/BYUvJl6Gfxk)

Github Awesome

22K views • 12 days ago

[![](https://i.ytimg.com/vi/QeOvk-VcHJU/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYZSBlKGUwDw==&rs=AOn4CLBJk5SiRskdTVkFvyTqzlGVpb_n5w)\\
\\
Shorts](https://www.youtube.com/shorts/QeOvk-VcHJU)

### [Agent Safehouse: Sandbox your LLM coding agents on macOS so they can only touch the files they need](https://www.youtube.com/shorts/QeOvk-VcHJU)

Github Awesome

26K views • 12 days ago

[![](https://i.ytimg.com/vi/10Ax1mxBBIA/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYWSBgKGUwDw==&rs=AOn4CLB9RNVI_T1RUwh9HKooaPAATqWerw)\\
\\
Shorts](https://www.youtube.com/shorts/10Ax1mxBBIA)

### [CLI-Anything: Making ALL Software Agent-Native](https://www.youtube.com/shorts/10Ax1mxBBIA)

Github Awesome

28K views • 13 days ago

[![](https://i.ytimg.com/vi/x5JYqsz8DWo/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYZSBlKGUwDw==&rs=AOn4CLC1h6sN5wHmCe-C-Gw7wiDpFzK8GQ)\\
\\
Shorts](https://www.youtube.com/shorts/x5JYqsz8DWo)

### [OpenCLI: Turn Any Website into a CLI](https://www.youtube.com/shorts/x5JYqsz8DWo)

Github Awesome

26K views • 3 days ago

New

[![](https://i.ytimg.com/vi/of2sthtXzyg/hq2.jpg?sqp=-oaymwFACKgBEF5IWvKriqkDMwgBFQAAiEIYANgBAeIBCggYEAIYBjgBQAHwAQH4AbYIgAL-DooCDAgAEAEYQiBVKGUwDw==&rs=AOn4CLBrBUvfeMLwT4_AH_9FPY7QyAnVrg)\\
\\
Shorts](https://www.youtube.com/shorts/of2sthtXzyg)

### [Impeccable: Give Your AI Real Design Skills](https://www.youtube.com/shorts/of2sthtXzyg)

Github Awesome

20K views • 2 days ago

New

[![](https://i.ytimg.com/vi/3kcAwY6aFuw/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLCG1IZSoxoZkggR01VP0sqPFyIrGQ)\\
\\
58:04](https://www.youtube.com/watch?v=3kcAwY6aFuw&list=RD3kcAwY6aFuw&start_radio=1&pp=oAcB)

### [Andrew Rayel - A State of Trance Episode 1269 Guest Mix](https://www.youtube.com/watch?v=3kcAwY6aFuw&list=RD3kcAwY6aFuw&start_radio=1&pp=oAcB)

A State Of Trance

6K views • 1 day ago

New

[![](https://i.ytimg.com/vi/_rHfEHVT6js/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDQWX21IEHa4HDIsYsiVeN-S1TV1A)\\
\\
1:12:25](https://www.youtube.com/watch?v=_rHfEHVT6js&list=RD_rHfEHVT6js&start_radio=1&pp=oAcB0gcJCcUKAYcqIYzv)

### [Whispering - Jazz Lullaby Music for Babies](https://www.youtube.com/watch?v=_rHfEHVT6js&list=RD_rHfEHVT6js&start_radio=1&pp=oAcB0gcJCcUKAYcqIYzv)

Songs of Birdland

204K views • 8 years ago

[![](https://i.ytimg.com/vi/aBzGDZGRXmM/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBl5EZHrr-PrPUgxVFG6P55D2pyEw)\\
\\
23:48](https://www.youtube.com/watch?v=aBzGDZGRXmM)

### [أسرار التكامل](https://www.youtube.com/watch?v=aBzGDZGRXmM)

حيدر عبدالائمة

and 2 more

701K views • 2 weeks ago

[![](https://i.ytimg.com/vi/0jHn9-EvvL8/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLDTw5vmWdMHLoRfwc50d3N4UkmZkQ)\\
\\
20:36](https://www.youtube.com/watch?v=0jHn9-EvvL8)

### [Will Israel Use Nuclear Weapons After Iran Targeted Dimona? \| The Samson Option \| Akash Banerjee](https://www.youtube.com/watch?v=0jHn9-EvvL8)

The Deshbhakt

2.5M views • 22 hours ago

New

[![](https://i.ytimg.com/vi/rGls8Eau6ls/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLC8IkkyL8NLZVcVRPE8b6O-FP5pwA)\\
\\
2:17](https://www.youtube.com/watch?v=rGls8Eau6ls)

### [Most Controversial Clip on the Internet Right Now](https://www.youtube.com/watch?v=rGls8Eau6ls)

Asmongold Clips

650K views • 11 hours ago

New

[![](https://i9.ytimg.com/s_p/PLZHQObOWTQDNPOjrT6KVlfJuKtYTftqH6/landscape_mqdefault.jpg?sqp=CPz0hM4Gir7X7AMICNyCheUFEAE=&rs=AOn4CLCvW-p_uSXcPeVzjmj9PtaGJ8hQiQ&v=1554071900)\\
\\
8 lessons](https://www.youtube.com/watch?v=p_di4Zn4wz4&list=PLZHQObOWTQDNPOjrT6KVlfJuKtYTftqH6)

### [Differential equations](https://www.youtube.com/watch?v=p_di4Zn4wz4&list=PLZHQObOWTQDNPOjrT6KVlfJuKtYTftqH6)

[3Blue1Brown](https://www.youtube.com/@3blue1brown) • [Course](https://www.youtube.com/@3blue1brown)

[View full course](https://www.youtube.com/playlist?list=PLZHQObOWTQDNPOjrT6KVlfJuKtYTftqH6)

[![](https://i.ytimg.com/vi/KdF5dkyVyxE/hqdefault.jpg?sqp=-oaymwEmCKgBEF5IWvKriqkDGQgBFQAAiEIYAdgBAeIBCggYEAIYBjgBQAE=&rs=AOn4CLBjM6pfWbXcdCUMJkxmPrpnbYluKQ)\\
\\
10:57](https://www.youtube.com/watch?v=KdF5dkyVyxE)

### [The Iranian leaders are gone, but things are going to get worse, here's why (Prof Xiang Xueqin)](https://www.youtube.com/watch?v=KdF5dkyVyxE)

Pr. Jiang Lectures

272K views • 20 hours ago

New